\NeedsTeXFormat{LaTeX2e}%
\ProvidesClass{psta}[2017/02/11 18:58:47 Document class for PSTA journal and UGP proceedings]
% Licensed with CC-BY-SA 
% Designed by S. Znamenskij, znamensk@rustex.botik.ru svz@latex.pereslavl.ru
%  
%%
% %% Options forwarding
%%
%
\RequirePackage{ifthen}
\newboolean{isDraft}
\setboolean{isDraft}{false}
\RequirePackage{kvoptions}
\RequirePackage{kvsetkeys}
\def\underliedclass{amsproc}%
\gdef\packages{textcase,cite,backref}

\makeatletter
\SetupKeyvalOptions{
    family=psta,
    prefix=psta@,
    setkeys=\kvsetkeys,}

\define@key{psta}{hyperref}{%
    \PassOptionsToPackage{#1}{hyperref}}

\define@key{psta}{babel}{%
    \PassOptionsToPackage{#1}{babel}}

\define@key{psta}{graphics}{%
    \PassOptionsToPackage{#1}{graphics}}

\def\DocumentEncoding{cp1251}%For compatibility
\DeclareOption{utf8}{\def\DocumentEncoding{utf8}\PassOptionsToPackage{inputenc}{utf8}}
\DeclareOption{koi8-r}{\def\DocumentEncoding{koi8-r}\PassOptionsToPackage{inputenc}{koi8-r}}

\ifx\pdfoutput\undefined\let\pdfoutput\z@\fi
\ifcase\pdfoutput
    \PassOptionsToPackage{dvips,hiresbb}{graphicx}%
\else
    \PassOptionsToPackage{pdftex}{graphicx,lscape}%
\fi
%%
%% 3. Specail options: Print (or view) and ugp 
%%
\def\@tempa{yn}
\DeclareOption{book}{\def\underliedclass{amsbook}}
\DeclareOption{article}{\def\underliedclass{amsart}}
\DeclareOption{literat}{\g@addto@macro\packages{,   literat}}
\DeclareOption{secsymbol}{\AtBeginDocument
    {\def\sectionmark{\pagebreak[2]\@secmark\markboth\sectionrunhead{\S\sectionname}}%
    \def\tocsection#1#2#3{\everypar {}\bigskip \noindent \parfillskip \z@ \leftskip .2\hsize plus.2 \hsize minus .2\hsize \rightskip
        \leftskip \textsf {#1}\par{\@ifempty{#2}{}{\textbf {\S#2. }} }{#3}}
    \def\@seccntformat#1{\S\csname the#1\endcsname.\hspace*{0.5em}}}}
\DeclareOption{print}{\def\@tempa{yy}}
\DeclareOption{hyphenbreaks}{\def\hyphenbreaks{y}}\def\hyphenbreaks{n}
\expandafter\ifx\csname Print\endcsname\relax\else\def\@tempa{11}\fi
\if\@tempa
    \PassOptionsToPackage{colorlinks,citecolor=black,urlcolor=black,linkcolor=black}{hyperref}%
\else
    \PassOptionsToPackage{backrefs}{amsrefs}%
        \PassOptionsToPackage{colorlinks,bookmarksopen,citecolor=citecolor,urlcolor=urlcolor,linkcolor=linkcolor}{hyperref}
\fi
\DeclareOption{ugp}{\def\PSTAforUGP{yy}}\def\PSTAforUGP{no}
\DeclareOption{ugp-doc}{\def\PSTAforUGP{yy}\def\UGPDOC{yy}}\def\UGPDOC{no}
\DeclareOption{fancy}{\def\fancyload{yy}}\def\fancyload{no}
\DeclareOption{minted}{\def\fancyload{yy}\def\mintedload{yy}}\def\mintedload{no}

\def\psta@bookmark{% default setting
    open,%
    numbered}

\define@key{psta}{bookmark}{%
    \g@addto@macro\psta@bookmark{,#1}}

\DeclareLocalOptions{bookmark}

\DeclareDefaultOption{%
    \PassOptionsToClass{\CurrentOption}{psta}}

\ProcessKeyvalOptions*

\def\@aIVpaper{no}\DeclareOption{a4paper}{\def\@aIVpaper{yy}}
\def\@tempa{no}
\DeclareOption{print}{\def\@tempa{yy}}
\DeclareOption{hyphenbreaks}{\def\hyphenbreaks{y}}\def\hyphenbreaks{n}
\expandafter\ifx\csname Print\endcsname\relax\else\def\@tempa{11}\fi
\if\@tempa
    \PassOptionsToPackage{colorlinks,citecolor=black,urlcolor=black,linkcolor=black}{hyperref}%
\else
    \PassOptionsToPackage{backrefs}{amsrefs}%
    \PassOptionsToPackage{colorlinks,bookmarksopen,citecolor=citecolor,urlcolor=urlcolor,linkcolor=linkcolor}{hyperref}
\fi
\DeclareOption{ugp}{\def\PSTAforUGP{yy}}\def\PSTAforUGP{no}
\DeclareOption{ugp-doc}{\def\PSTAforUGP{yy}\def\UGPDOC{yy}}\def\UGPDOC{no}
\DeclareOption{fancy}{\def\fancyload{yy}}\def\fancyload{no}
\DeclareOption{minted}{\def\fancyload{yy}\def\mintedload{yy}}\def\mintedload{no}
\def\classoptions{}
\DeclareOption*{\expandafter\g@addto@macro\expandafter\classoptions\expandafter{\expandafter,\CurrentOption}}
\ProcessOptions*\@options \relax
%
%%
% %%  Package with options loading
%%
%
%%
%% 1. Before hyperref 
%%
\AtBeginDocument{\let\document@language=\languagename\csname bib@set@\languagename\endcsname\advance\baselineskip 0ptplus.35ptminus.25pt}
\ifcase\pdfoutput
    \IfFileExists{srcltx.sty}{\RequirePackage[active]{srcltx}}{}
\else
    \RequirePackage{cmap}
\fi
\RequirePackage{floatrow}
\floatsetup[table]{capposition=top}
\RequirePackage[T2A]{fontenc}%
\RequirePackage[cp1251]{inputenc}%
\RequirePackage[english,russian]{babel}%
\LoadClass[\classoptions]{\underliedclass}%
%%%%%%%%%%%%%%%  Page numbering
\IfFileExists{psta-join.tex}{\RequirePackage{microtype}}{}
\IfFileExists{xcolor.sty}{\RequirePackage{xcolor}}{\RequirePackage{color}}
\definecolor{lightgray}{rgb}{0.5,0.5,0.5}
\definecolor{citecolor}{rgb}{0,0.3,0.25}
\definecolor{urlcolor}{rgb}{0.4,0,0.1}
\definecolor{linkcolor}{rgb}{0,0.2,0.5}
\definecolor{backrefcolor}{rgb}{0.55,0.55,0.55}
\definecolor{verbatimrules}{rgb}{0.1,0.3,.2}
\definecolor{verbatimbgu}{rgb}{.85,0.97,.9}
\definecolor{verbatimbg}{rgb}{.92,1,.92}
\definecolor{verbatimtitle}{rgb}{0.1,0.4,0.2}
\definecolor{verbatimnumbers}{rgb}{0.7,0.8,0.8}
\definecolor{verbatimdefault}{rgb}{0.25,0.2,0.3}
\definecolor{authorsmarks}{rgb}{0.4,0.6,0.4}
\definecolor{string}{rgb}{0.45,0.45,0.1}
\definecolor{gt}{rgb}{0.55,0.75,0.45}
\definecolor{word}{rgb}{0.25,0.25,0.25}
\definecolor{key}{rgb}{0.1,0.4,0.1}
\definecolor{variable}{rgb}{0.4,0,0}
\definecolor{comment}{rgb}{0.15,0.2,0.6}
\definecolor{parameter}{rgb}{0,0.2,0.5}
\def\thepage{\arabic{page}}
\def\autopages#1#2#3#4{\expandafter
    \def\csname First page of #3\endcsname{#1}\expandafter
    \def\csname Last page of #3\endcsname{#2}}
\def\firstpageof#1{\csname First page of #1\endcsname}
\def\lastpageof#1{\csname Last page of #1\endcsname}
\def\@ifpages#1{\expandafter\expandafter\expandafter
    \ifx\firstpageof{#1}\relax\expandafter\@secondoftwo\else\expandafter\@firstoftwo\fi}
%%
%% 2 Hyperref and other after  
%%
\usepackage[hyphens]{url}

\RequirePackage[pagebackref,unicode]{hyperref}
\RequirePackage{bookmark}  
\expandafter\bookmarksetup\expandafter{\psta@bookmark}
\expandafter\RequirePackage\expandafter{\packages}
\RequirePackage{lastpage}
\RequirePackage[figure,table]{totalcount}
\RequirePackage[citation-order,sorted-cites,compressed-cites,initials,sorted-cites,compressed-cites,backrefs,nobysame]{amsrefs}
\RequirePackage{enumitem}
\setlist[enumerate,1]{labelindent=0cm, labelwidth=5pt, itemindent=5pt,leftmargin=10pt,rightmargin=5pt}
\setlist[itemize,1]{labelindent=0cm, labelwidth=3pt, itemindent=3pt,leftmargin=10pt,rightmargin=5pt,label=\copy\pstabulletbox}
\setlist[description,1]{labelindent=3pt, labelwidth=1pc, leftmargin=10pt,rightmargin=6pt,style=unboxed}
\renewcommand{\descriptionlabel}[1]{\hspace\labelsep{\scalebox{1.05}{\emph{#1}}}}
\def\FV@Space{\kern.5em}
\def\pstarus#1#2{\russian@alph{\csname c@#2\endcsname}}
\def\pstarualf#1{{\footnotesize\textsf(}\textit{#1\pstarus\alph*}{\footnotesize\textsf)}}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand\WerbatimToken[1]{\edef#1{\string#1}}%
\WerbatimToken\EndWeed
\WerbatimToken\Bound
\WerbatimToken\Weed@Cursor
\WerbatimToken\Weed@@Cursor
\let\wlogpsta\wlog
%\let\wlogpsta\@gobble
\gdef\@secondfirstoftwo#1#2{#2#1}
% Inspired by the Package{domore}[2013/03/22] by Uwe Lueck
\def\@@ifx#1#2#3#4{\ifx#1#2\expandafter\@firstoftwo\else\expandafter\@secondoftwo\fi{#3}{#4}}%
%\def\@@ifx#1#2#3#4{\ifx#1#2\expandafter\@firstoftwo\else\expandafter\@secondoftwo\fi{\wlog{[\string#1=\string#2]}#3}{\wlog{[\string#1=\meaning#1^^J!=\string#2]}#4}}%
\def\TestThisMacro#1\\{\message{\string #1^^J\@spaces\@spaces\@spaces#1^^J}}%
%\def\TestThisMacro#1\\{}
%%%%%%%%%%%  MACRO \ArrangeList ,<|12345|>=- PRODUCE  ={<1,2,3,4,5>}
%                  \ArrangeList ,<||>=-      PRODUCE  -
% No grouping to be allowed instead of |12345 here, just a single tokens!!! 
\def\ArrangeList#1#2#3#4{\@@ifx#3#4{\@thirdofthree}{\ArrangeList@{#1}{#2#4}#3}}%
% LastStep:   \ArrangeList@ {,}{<1234}|5|>=-   =>  \ArrangeList@ {,}{<1,2345}||>=-
\def\ArrangeList@#1#2#3#4{\@@ifx#3#4{\ArrangeList@@{#2}}{\ArrangeList@{#1}{#2#1#4}#3}}%
\def\ArrangeList@@#1#2#3#4{#3{#1#2}}%
%\TestThisMacro \ArrangeList ,<|12345|>=- \\
%\TestThisMacro \ArrangeList ,<||>=- \\     
% 
%%%%%%%%%%%  MACRO  \Weed {1121\relax 22779211}{AFTER}  PRODUCE  AFTER{1279) 
%
\long\def \Weed#1{\Weed@@Check\Weed@Cursor\Weed@@Cursor#1\EndWeed}
\long\def \Weed@@Check#1\Weed@Cursor#2\Weed@@Cursor#3{%
    \@@ifx#3\EndWeed
       {\@secondfirstoftwo{{#1#2}}}%
       {\@@ifx#3\relax
          {\Weed@@Check#1\Weed@Cursor#2\Weed@@Cursor}
          {\Weed@Check#1\Weed@Cursor#2\Weed@@Cursor#3}}} 
\long\def \Weed@Check#1\Weed@Cursor#2#3{%
    \@@ifx#2\Weed@@Cursor{\WeedCompare@@#1\Weed@Cursor#3#2}%
    {\@@ifx#2\relax
        {\Weed@@Check#1\Weed@Cursor#3}%
        {\@@ifx#3\Weed@@Cursor\WeedCompare@@\WeedCompare@#1\Weed@Cursor#2#3}}}%
\long\def \WeedCompare@@#1\Weed@Cursor#2\Weed@@Cursor#3{%
    \@@ifx#3\EndWeed
       {\@secondfirstoftwo{{#1#2}}}%
          {\@@ifx#2#3%
                {\Weed@Check\Weed@Cursor#1#2\Weed@@Cursor}%
                {\Weed@Check\Weed@Cursor#1#2#3\Weed@@Cursor}}}
\long\def \WeedCompare@#1\Weed@Cursor#2#3\Weed@@Cursor#4{%
    \@@ifx#4\relax
        {\Weed@Check\Weed@Cursor#1#2#3\Weed@@Cursor}%
        {\@@ifx#2#4%
            {\Weed@Check\Weed@Cursor#1#2#3\Weed@@Cursor}%
            {\Weed@Check#1#2\Weed@Cursor#3\Weed@@Cursor#4}}}
%
%   \tracingall
%\TestThisMacro \Weed {112122779211}{AFTER}\\
%\TestThisMacro \Weed{\relax \relax 112\relax \relax 122779211\relax \relax}{AFTER}\\
%\TestThisMacro \Weed {12\relax \relax 122779}{AFTER}\\
%\TestThisMacro \Weed {1\relax 1\relax 122779}{AFTER}\\
%\TestThisMacro \Weed {\relax 12\relax 122779\relax }{AFTER}\\
%
\def\@ifrus{\ifnum\language=\l@russian \expandafter\@firstoftwo\else\expandafter\@secondoftwo\fi}
%%%%%%%%%%%%%%%  General Cyrillic support  %%%%%%%%%%%%%%%%%%%%%%%%
\def\orgdef#1\\ #2\\ #3\\ #4\\ #5\\ {%
    \expandafter\def\csname #1\endcsname{\csname\the\language#1\endcsname}%
    \language=\l@english
    \expandafter\def\csname\the\language#1\endcsname{\href{http://#2}{#3}}%
    \language=\l@russian
    \expandafter\def\csname\the\language#1\endcsname{\href{http://#4}{#5}}}
\def\EnglishRussianCaption#1#2#3{\expandafter
    \edef\csname EnglishCaption\string#1\endcsname{#2}\expandafter
    \edef\csname RussianCaption\string#1\endcsname{#3}\expandafter\expandafter\expandafter
    \addto\expandafter\expandafter\expandafter
    \captionsrussian\expandafter\expandafter\expandafter
    {\expandafter\expandafter\expandafter
    \def\expandafter\expandafter\expandafter
    #1\expandafter\expandafter\expandafter
    {\csname RussianCaption\string#1\expandafter\expandafter\expandafter
    \endcsname\expandafter\expandafter\expandafter
    }\expandafter\expandafter\expandafter
    }\expandafter\expandafter\expandafter
    \addto\expandafter\expandafter\expandafter
    \captionsenglish\expandafter\expandafter\expandafter
    {\expandafter\expandafter\expandafter
    \def\expandafter\expandafter\expandafter
    #1\expandafter\expandafter\expandafter
    {\csname EnglishCaption\string#1\expandafter\expandafter\expandafter
    \endcsname}}}
\DefineName{etc}{\Etcname}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%% author related
\catcode`\'=11
\def\AG@abbreviate@author#1{\expandafter\AG@name@split #1,{},{},{},\@nil
    \expandafter\@ifempty\expandafter{\the\AG@shortauthors}{%
        \expandafter\expandafter\expandafter
        \AG@groupswap\expandafter\expandafter\expandafter    
        {\expandafter \bib'initials\expandafter~\bib'surname}%
        {\AG@shortauthors}{}}{\expandafter\expandafter\expandafter
        \AG@groupswap\expandafter\expandafter\expandafter    
        {\expandafter \bib'initials\expandafter~\bib'surname}%
        {\AG@shortauthors\expandafter}{\the\AG@shortauthors, }}
   % \tracingmacros=0
    }
\def\AG@groupswap#1#2#3{#2{#3#1}}%
\def\AG@name@split#1,#2#3,#4#5,#6\@nil{%
  \def\bib'surname{#1}%
  \ifx\bib'surname\@empty \EmptyNameWarning\fi
  \def\bib'given{#2#3}%
  \def\bib'jr{#4#5}%
  \ifx\@empty\bib'given \NameCheck #1 ??\@nil
  \else \extract@initials{#2#3}%
  \fi
}
\def\@count@chars#1{\ifx \@nil#1\empty\else \advance \@tempcnta \@ne \@xp \@count@chars \fi} 
\def\bib@field@patches{%
    \ifx\bib'author\@empty
        \ifx\bib'editor\@empty
            \let\current@primary\bib'translator
            \let\print@primary\PrintTranslatorsA
        \else
            \let\current@primary\bib'editor
            \let\print@primary\PrintEditorsA
        \fi
    \else
        \let\current@primary\bib'author
        \let\print@primary\PrintAuthors
    \fi
    \ifx\bib'address\@empty
        \let\bib'address\bib'place
    \fi
    \ifx\bib'organization\@empty
        \ifx\bib'institution\@empty
            \let\bib'organization\bib'school
        \else
            \let\bib'organization\bib'institution
        \fi
    \fi
    \ifx\bib'date\@empty
        \ifx\bib'year\@empty
            \let\bib@year\bib'status
        \else
            \bib@parsedate\bib'year
        \fi
    \else
        \bib@parsedate\bib'date
    \fi
    \def\@tempa{year}%
    \ifx\bib'volume\@tempa
        \let\bib'volume\bib@year
        \let\bib'date\@empty
    \fi
%    \ifx\setbib@@\setbib@article
%        \ifx\bib'volume\@empty
%            \ifx\bib'number\@empty\else
%                \let\bib'volume\bib'number
%                \let\bib'number\@empty
%            \fi
%        \fi
%    \fi
    \bib@language@fixup
}

\renewcommand{\PrintNames@a}[4]{%
    \PrintSeries{\name}
        {#1}
        {,}{ \set@othername}
        {,}{ \set@othername}
        {,}{ \set@othername}
        {#2}{#4}{#3}%
}
\def\InitialPunct{.}
\BibSpec{firstauthor}{
   +{}{}{surname}
   +{}{ }{initials}
   +{}{ \parenthesize}{jr}
  }
\BibSpec{coauthor}{
   +{,}{ }{transition}
   +{}{ }{surname}
   +{}{ }{initials}
   +{}{ \parenthesize}{jr}
  }
\BibSpec{middleauthor}{
   +{,}{ }{transition}
   +{}{ }{surname}
   +{}{ }{initials}
   +{}{ \parenthesize}{jr}
  }
\BibSpec{lastauthor}{
   +{,}{ }{transition}
   +{}{ }{surname}
   +{}{ }{initials}
   +{}{ }{jr}
  }
\def\biblanguageEnglish{english}
\let\biblanguagedefault\biblanguageEnglish

\BibSpecAlias{firsteditor}{firstauthor}
\BibSpecAlias{issue}{number}
\BibSpecAlias{coeditor}{coauthor}
\BibSpecAlias{middleeditor}{coeditor}
\BibSpecAlias{lasteditor}{coeditor}
\BibSpec{firsted}{
 +{}{}{initials}
 +{}{ }{surname}
 +{}{ }{jr}
}
\BibSpec{coed}{
 +{,}{ }{initials}
 +{}{ }{surname}
 +{}{ }{jr}
}
\BibSpec{middleed}{
 +{,}{ }{initials}
 +{}{ }{surname}
 +{}{ }{jr}
}
\BibSpec{lasted}{
 +{,}{ }{initials}
 +{}{ }{surname}
 +{}{ }{jr}
}
\def\bib@language@fixup{%    
    \ifx\bib'hyphenation\@empty
        \ifx\bib'language\@empty
            \expandafter\find@noncyr\bib'author\@nill 
            \edef\bib@language{\bib@cyr@lat{russian}{english}}%
        \else
            \let\bib@language\bib'language
        \fi
    \else
        \let\bib@language\bib'hyphenation
    \fi
   % \expandafter\aftergroup
    \csname bib@set@\bib@language\endcsname
    \def\@tempa##1 ##2\@nil{\lowercase{\def\bib@language{##1}}}%
    \@firstofone{\@xp\@tempa\bib@language} \@nil}
\let\bib@selectlanguage@\bib@selectlanguage
\def\bib@selectlanguage{\afterassignment\bib@selectlanguage@
    \bib@language@fixup}
\def\emdash{\---}%
\font\bib@author@font=lacc1000 at 6.5pt
\def\PrintAuthorList#1{{\bib@author@font{\PrintNames{}{}{#1}}}}
\def\find@noncyr#1\@nill{\open@names#1\name{}\@nill}%
\def\open@names#1\name#2#3\@nill{\@ifempty{#2}%
    {\lowercase{\lookfor@v#1v\@nill}}%
    {\open@names#1#2#3\@nill}}

\def\AMS@IoC#1{{\noexpand\IoC#1}}
\def\AMS@UTFviii@two@octets#1#2{{\noexpand\UTFviii@two@octets\string #1\string#2}}
\def\AMS@UTFviii@three@octets#1#2#3{{\noexpand\UTFviii@three@octets\string #1\string#2\string#3}}
\def\AMS@UTFviii@four@octets#1#2#3#4{{\noexpand\UTFviii@four@octets\string #1\string#2\string#3\string#4}}

\def\extract@initials#1{\@extract@initials{#1}{\edef\@tempa{\def\@nx\bib'initials{\@tempa}}}}
\catcode`\'=12
\def\@extract@initials#1#2{%
    \begingroup
        \auto@protect\ini@hyphen
        \auto@protect\nobreakspace
        \let\-=\@empty
        \let~\relax
        \let\IoC\AMS@IoC
        \let\UTFviii@two@octets\AMS@UTFviii@two@octets
        \let\UTFviii@three@octets\AMS@UTFviii@three@octets
        \let\UTFviii@four@octets\AMS@UTFviii@four@octets
        \@apply\auto@protect\amsrefs@textsymbols
        \@apply\auto@protect\amsrefs@textaccents
        \normalize@edef\@tempa{#1}%
        \auto@protect\UTFviii@two@octets
        \auto@protect\UTFviii@three@octets    
        \auto@protect\UTFviii@four@octets    
        \auto@protect\IoC
        \ifx\@tempa\@empty
        \else
            \process@hyphens\@tempa
            \process@dots\@tempa
            \process@names\@tempa
            \@chomp\@tempa{~}%
        \fi
        %\show\@tempa
        #2\@xp\endgroup
    \@tempa
}
   
\def\@lookfor#1{\csname @lookfor#1\endcsname}
\def\reserved@a#1#2{\expandafter\def\csname lookfor@#1\endcsname ##1#1##2\@nill
        {\@ifempty{##2}{\csname lookfor@#2\endcsname##1#2\@nill}{\bib@set@lat}}}
\reserved@a vh\reserved@a ht\reserved@a tb\reserved@a bd\reserved@a df\reserved@a
    fg\reserved@a gj\reserved@a  jk\reserved@a ks\reserved@a  sl\reserved@a
    lm\reserved@a mn\reserved@a nq\reserved@a qu\reserved@a
    uw\reserved@a wx\reserved@a xy\reserved@a
    yz\reserved@a z{end}%
\def\lookfor@end#1\@nill{\bib@set@cyr}%
\def\bib@set@lat{%\message{(bib-lat)}
    \let\bib@cyr@lat\@secondoftwo}
\def\bib@set@cyr{%\message{(bib-cyr)}
        \let\bib@cyr@lat\@firstoftwo}
\let\bib@set@russian\bib@set@cyr
\let\bib@set@english\bib@set@lat
\let\bib@set@french\bib@set@lat

%\let\bib@author@font\normalfont

\let\bib@title@font\textit
\let\bib@volume@font\textbf
\def\EnglishInitialCaps#1{#1}%
\def\@eprint{{\scriptsize \textsf{URL:} }\eprint}
\BibSpec{collection.article}{%
    +{}  {\PrintAuthors}                {author}
  +{.}{ \textit}{title}
  +{}{  // \EnglishInitialCaps}{booktitle}
  +{}{  // \EnglishInitialCaps}{conference}
  +{:}{ }{subtitle}
  +{:}{ }{type}
  +{.}{ }{series}
  +{/}{ }{organization}
  +{}{ / \bib@cyr@lat{\bibedstext~\PrintAuthors}{\PrintEditorsA}}{editor}
  +{. \emdash}{ \PrintEdition}{edition}
  +{.}{ \emdash}{place}
  +{:}{ }{publisher}
  +{,}{ \PrintDateB}{date}
  +{.}{ \bibParttext~}{part}
  +{.}{ \bibVoltext~\bib@volume@font}{volume}
  +{,}{ \bibissuetext~}{number}
  +{}{ \parenthesize}{status}
  +{,}{ \bibpagetext~}{pages}
  +{.}{}{transition}
  +{,}{ \@eprint}{eprint}
  +{.}{}{transition}
  +{,}{ }{note}
  +{.}{}{transition}
  +{}{\SentenceSpace \ReviewList}{review}
  +{}{ \parenthesize}{language}
}
\BibSpec{article}{%
    +{}  {\PrintAuthors}                {author}
  +{.}{ \textit}{title}
  %  +{,} { \textit}                     {title}
  %  +{.} { }                            {part}
  +{:}{ }             {part}
    +{:} { \textit}                     {subtitle}
    +{,} { \PrintContributions}         {contribution}
    +{.} { \PrintPartials}              {partial}
  +{}{ // }             {journal}
 %   +{,} { }                            {journal}
  +{.}{ }{series}
  +{,}{ \PrintDateB}{date}
  +{.}{ \bibVoltext~\textbf}      {volume}
  +{,}{ \bibissuetext~}{number}
  +{,}{ \bibpagetext~}  {pages}
  +{} { \parenthesize}{status}
  +{,}{ \PrintDOI}    {doi}
  +{}{ \parenthesize}{language}
  +{}  { \PrintTranslation}           {translation}
  +{,}{ \@eprint}      {eprint}
  +{,}{ }             {note}
  +{.}{}              {transition}
}
\BibSpec{book}{%\DefineSimpleKey{bib}{issue}
    +{}  {\PrintAuthors}                {author}
  +{.}{ }{title}
  +{}{  // \EnglishInitialCaps}{booktitle}
  +{:}{ }{subtitle}
  +{:}{ }{type}
  +{.}{ }{series}
  +{ }{/ }{organization}
  +{}{ / \bib@cyr@lat{\bibedstext~\PrintAuthors}{\PrintEditorsB}}{editor}
  +{.}{ \PrintEdition}{edition}
  +{,}{ \bibvoltext~\bib@volume@font}{volume}
  +{.}{ }{place}
  +{:}{ }{publisher}
  +{,}{ \PrintDateB}{date}
  +{. }{ \bibParttext~}{part}
  +{,}{ \bibissuetext~}{number}
  +{}{ \parenthesize}{status}
  +{. \emdash}{ \PrintPages}{pages}
  +{.}{ }{note}
  +{.}{}{transition}
  +{}{\SentenceSpace \ReviewList}{review}
  +{}{ \parenthesize}{language}
  }
 
\BibSpec{report}{%
  +{}{\PrintAuthors}{author}
  +{.}{ \textit}{title}
  +{:}{ }{type}
  +{}{  // \EnglishInitialCaps}{booktitle}
  +{:}{ }{subtitle}
  +{.}{ }{series}
  +{/}{ }{organization}
  +{}{ / \bib@cyr@lat{\bibedstext~\PrintAuthors}{\PrintEditorsB}}{editor}
  +{.}{ \PrintEdition}{edition}
  +{.}{ }{place}
  +{:}{ }{publisher}
  +{,}{ }{institution}
  +{,}{ \PrintDateB}{date}
  +{.}{ \bibVoltext~\bib@volume@font}{volume}
  +{.}{ \bibParttext~}{part}
  +{,}{ \bibissuetext~}{number}
  +{,}{ \@eprint}      {eprint}
  +{}{ \parenthesize}{status}
  +{. ---}{ \PrintPages}{pages}
  +{.}{}{transition}
  +{,}{ }{note}
  +{.}{}{transition}
  +{}{\SentenceSpace \ReviewList}{review}
  +{}{ \parenthesize}{language}
}
\BibSpec{thesis}{%
  +{}{\PrintAuthors}{author}
  +{}{ / \bib@cyr@lat{\bibedstext~\PrintAuthors}{\PrintEditorsC}}{editor}
  +{.}{ \textit}{title}
  +{,}{ \PrintThesisType}{type}
  +{,}{ }{organization}
  +{,}{ }{institution}
  +{,}{ }{place}
  +{,}{ \PrintDate}{date}
  +{}{ \parenthesize}{status}
  +{,}{ }{note}
  +{.}{}{transition}
  +{.}{ \bibParttext~}{part}
  +{. ---}{ \PrintPages}{pages}
  +{,}{ \@eprint}{eprint}
  +{.}{}{transition}
  +{}{\SentenceSpace \ReviewList}{review}
  +{}{ \parenthesize}{language}
}
\def\etcname{\bib@cyr@lat{\Etcname}{etc.}}%
\newcommand\PrintPages[1]{#1~\bibpagetext}

%%%%%%%% End of file amsrefsgost.sty
%%%%%%%%
\PassOptionsToPackage{amsmath}{intlimits,sumlimits,namelimits,centertags}
\RequirePackage{amssymb,amscd,euscript}% 
\let\equation\gather \let\endequation\endgather
\RequirePackage{nameref,color,graphics,lscape,upref,rotating}
\RequirePackage{array}\setlength{\extrarowheight}{1pt}
\RequirePackage[shortcuts,cyremdash]{extdash}%
\newbox\pstabulletbox\setbox\pstabulletbox\hbox{\raise.3ex\hbox{\scalebox{1}[.6]{\hbox{$\bullet$}}}} 
%
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%% subjclass related
\newcommand\format@subjclass[2]{{\noindent\Small
    \@ifundefined{subjclassname@#1}{\ClassWarning {\@classname}{Unknown Subject Classification!}}
    {\@nameuse{subjclassname@#1}{#2}}}}
\renewcommand*\subjclass[2][1991]{\l@Arg\g@addto@macro{setsubjclasses}{\format@subjclass{#1}{#2}}}
\expandafter\gdef\csname russian-setsubjclasses\endcsname{}%
\expandafter\gdef\csname english-setsubjclasses\endcsname{}%
\@namedef{subjclassname@1999}#1{\SCAformat@{1999}{#1}}%
\@namedef{subjclassname@2000}#1{\SCAformat@{2000}{#1}}%
\@namedef{subjclassname@2010}#1{\SCAformat@{2010}{#1}}%
\@namedef{subjclassname@UDC}#1{\fontSC@A{\UDCname %\fontSC@B
    {} #1}}
\@namedef{subjclassname@UDK}#1{\fontSC@A{\UDCname %\fontSC@B
    {} #1}}
\@namedef{subjclassname@BBC}#1{\fontSC@A{\BBCname %\fontSC@B
    {} #1}}
\@namedef{subjclassname@BBK}#1{\fontSC@A{\BBCname %\fontSC@B
    {} #1}}
\def\fontSC@A#1{{\tiny{#1}}}
\def\fontSC@B#1{{\footnotesize\textsf{#1}}}%
\def\fontSC@C#1{{\scriptsize\textit{#1}}}
\def\SCAformat@#1#2{\fontSC@A{#1} \fontSC@C {Mathematics Subject Classification}\/: \fontSC@B{#2}}%
\def\set@logo#1{\hbox to\hsize{\fontsize{6}{7\p@}#1}}
\AtBeginDocument{\def\PrintBackRefs#1{\space \SentenceSpace \textcolor{backrefcolor}{$\uparrow $ \csname br@#1\endcsname}.}} 

% %% Paper design
%%
%
%%
%% 1. Page Dimensions 
%%
\def\ps@firstpage{\ps@plain
  \def\@oddfoot{}%
  \let\@evenfoot\@oddfoot
  \def\@oddhead{\@serieslogo}%
  \let\@evenhead\@oddhead % in case an article starts on a left-hand page
}
\def\PSI@pagesetup{%
\if\@aIVpaper
    \paperheight 300mm
    \paperwidth 210mm
    \hoffset -1in
    \voffset -1in
    \topmargin=12mm
    \headheight=8mm
    \headsep=7mm
    \parskip1ptplus1pt
    \evensidemargin=18.5mm
    \oddsidemargin=18.5mm
    \footskip=0pt
    \textheight = 257 mm %=171-12-15-8-4, from OST 29.124-94 margins 10..24-12-15-11 +2mm trim
    \textwidth  = 171 mm %=148.5-13-24
\else
    \paperheight 210mm
    \paperwidth 148mm
    \hoffset -1in
    \voffset -1in
    \topmargin=12mm
    \headheight=8mm
    \headsep=4mm
    \parskip1ptplus1pt
    \evensidemargin=18.5mm
    \oddsidemargin=18.5mm
    \footskip=0pt
    \textheight = 167 mm %=171-12-15-8-4, from OST 29.124-94 margins 10..24-12-15-11 +2mm trim
    \textwidth  = 111 mm %=148.5-13-24
  \fi}
\PSI@pagesetup
\widowpenalty=500
\clubpenalty=500
\brokenpenalty=500
\interlinepenalty=100
\AtBeginDocument{\def\verbatim@font{\Small\ttfamily}\thispagestyle{empty}}%
%%
%% 2. Headline and strings 
%%
\newcounter{psta}
\ifx\PSTAUndefined\Year 
    \ifx\PSTAUndefined\PSTAyear 
        \c@psta = \year
        \edef\Year{\number\year}%
        \edef\PSTAyear{\Year}%
    \else 
        \c@psta = \PSTAyear
        \edef\Year{\PSTAyear}%
    \fi
\else 
    \ifx\PSTAUndefined\PSTAyear 
        \edef\PSTAYear{\Year}%
    \fi
    \c@psta = \PSTAyear
\fi
\if\PSTAforUGP
    \advance\c@psta-1996
    \edef\numberofConf{\expandafter\uppercase\expandafter{\romannumeral\c@psta}}
    \edef\issuename{sit\Year}
\else
\ifx\PSTAUndefined\PSTAissue
    \edef\Volume{??}%
    \edef\Numissue{?}%
    \edef\issuename{\jobname}
\else
    \advance\c@psta-2009 
    \edef\Volume{\number\c@psta}
    \advance\c@psta-1 
    \multiply\c@psta 4
    \ifnum\Volume>2\advance\c@psta1\fi
    \ifnum\Volume>3\advance\c@psta1\fi
    \ifnum\Volume>5\advance\c@psta1\fi
    \advance\c@psta\PSTAissue 
    \edef\Numissue{\PSTAissue(\number\c@psta)}%
    \InputIfFileExists{comments.tex}{}{}%
    \edef\issuename{psta\Year\_\PSTAissue}
\fi
\fi
\if\PSTAforUGP
    \xdef\pstaurl{https://edu.botik.ru/proceedings/sit\PSTAyear.pdf}
    \else\ifx\pagerange\PSTAUnDefined
    \gdef\pstaurl{http://psta.psiras.ru/read/}\else
    \gdef\pstaurl{http://psta.psiras.ru/read/psta\PSTAyear\_\PSTAissue\_\pagerange.pdf}\fi\fi
\@ifundefined{pagerange}{\let \formatPagerange\relax\def \pagerange{??--??}}{%
\def\formatPagerange#1{\expandafter\formatPagerange@#1-;\endPagerange}}
\def\formatPagerange@#1-#2#3\endPagerange{\formatPagerange@@#1-;\endPagerange
    \if;#2\else--\formatPagerange@@#2#3\endPagerange\fi}
\def\formatPagerange@@#1-;\endPagerange{%\href[page=#1]{\issuename}%
{#1}}
\pagestyle{headings}
\def\ps@headings{\ps@empty
  \def\@evenhead{%
    \setTrue{runhead}%
    \normalfont\scriptsize
    \rlap{\thepage}\hfil \hbox to .9\hsize
    {\let\ \space\hfil\scshape{\leftmark{}{}}\hfil\hskip0ptminus.04\hsize}\hfil}%
  \def\@oddhead{%
    \setTrue{runhead}%
    \normalfont\scriptsize \hfil \hbox to .9\hsize{
    \hfil\hskip0ptminus.04\hsize
    \scshape{\let\ \space\rightmark{}{}}\hfil}\hfil \llap{\thepage}}%
\let\@mkboth\markboth}
\if\PSTAforUGP
\AtBeginDocument{\def\LinkToHomepage{\UGP}}
    \def\publname{{\ifx\thisISBN\UnDefined
            \font\colonTitlefont=labx1000  at 7.7pt
            \font\colonTitleTextfont=labx1000  at 6.5pt 
        \else
            \font\colonTitlefont=labx1000  at 4.3pt \font\colonTitleTextfont=labx1000 at 3.8pt    
        \colonTitleTextfont ISBN {\colonTitlefont\thisISBN} %  
        \fi
        \footnotesize\scshape 
        SIT-\PSTAyear\hss
        \SIT 
         %\placename{: }
        \hss 
        \pagestext~\expandafter\formatPagerange\expandafter{\pagerange}}}
\else
\AtBeginDocument{\def \LinkToHomepage{\PSTA}}
    \font\colonTitlefont=labx1000  at 5pt%
    \font\colonTitleTextfont=labx1000  at 6pt%
    \def\publname{{\headlinelanguage{\colonTitlefont ISSN  2079-3316 \textcolor{urlcolor}{{ \colonTitleTextfont \PSTAup{} }} 
    \bibissuetext \Numissue, \Year, \pagestext~\expandafter\formatPagerange\expandafter{\pagerange}}}}
\fi

\def\@captionheadfont{\small\scshape}
\def\@captionfont{\small}

%%
%% 3. Title page and last page  
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%% authors related
%% 1. Record data 
%

\def\setlang#1{\let#1=\languagename\g@addto@macro\languagelist#1}
\gdef\langshow#1{\wlog{\l@Arg\string{#1}=\l@Arg\meaning{#1}}}
\newcommand\l@ifundefined[1]{\@ifundefined{\languagename-#1}}
\def\mk@Arg#1#2{\expandafter#1\csname#2\endcsname}
\def\l@Arg#1#2{\expandafter#1\csname\languagename-#2\endcsname}
\newcommand\l@nameuse[1]{\l@Arg{}{#1}}
\newcommand\l@namedef[1]{\l@Arg\def{#1}}
\newcommand\l@nameedef[1]{\l@Arg\edef{#1}}
\def\tracing#1 {\tracingmacros #1 \tracingcommands #1 \tracingassigns #1  \tracinggroups #1 
\tracingrestores #1 \tracingifs #1 \tracingoutput #1 \showboxbreadth #1 \showboxdepth #1}

\def\l@casenew#1#2#3{% #1 detokenised #2 full #3 class
    \ifx#1\relax 
    \l@ifundefined{#3.id}{\count@=1 }{%
        \l@Arg\count@{#3.id}%
        \advance \count@ 1}%  
    \l@Arg\xdef{#3.id}{\number\count@}%
    \langshow{#3.id}%
    \l@Arg\def{#3.\number\count@}{#2}%
    \langshow{#3.\number\count@}%
    \xdef#1{\number\count@}%
    \wlog{\string#1=\meaning#1}%
    \l@tolist{#3-s}{#3.id}{#3}%
    \else \count@ #1 \fi 
}
    
\def\l@tolist#1#2#3{% #1-{short list name}; #2 {short item id}; #3 CLASS OF LISTS;
    \l@ifundefined{#1.list}%
    {\l@Arg\gdef{#1.list\expandafter}\expandafter
    {\csname#3-format\expandafter\expandafter\expandafter\endcsname
        \expandafter\expandafter\expandafter
    {\csname\languagename-#2\endcsname}}}%
    {\l@Arg\g@addto@macro{#1.list\expandafter}\expandafter
    {\csname#3-join\expandafter\endcsname
    \csname#3-format\expandafter\expandafter\expandafter\endcsname\expandafter\expandafter\expandafter
    {\csname\languagename-#2\endcsname}}}%
    \wlog{\l@Arg\string{#1.list}=\l@Arg\meaning{#1.list}}%
}  
\def\Zero@{0}
\def\new@l@data@#1{\expandafter
    \def\csname#1\endcsname##1{%
        \@ifundefined{role@}{%
        \l@Arg\def{author.0.#1}{##1}%
        \wlog{\l@Arg\string{author.0.#1}=\l@Arg\meaning{author.0.#1}}%
        \expandafter\l@casenew\csname\languagename-#1=\detokenize{##1}\endcsname{##1}{#1}%
        \l@tolist{authors-with-#1.0}{Zero@}{#1-of-author}%
        }{%
        \l@Arg\def{\role@\l@Arg.{\role@.id}.#1}{##1}%
        \wlog{\l@Arg\string{\role@\l@Arg.{\role@.id}.#1}=\l@Arg\meaning{\role@\l@Arg.{\role@.id}.#1}}%
        \expandafter\l@casenew\csname\languagename-#1=\detokenize{##1}\endcsname{##1}{#1}%
        \l@tolist{\role@ s-with-#1.\number\count@}{\role@.id}{#1-of-\role@}}}}
\gdef\languagelist{}\gdef\persons{}\gdef\authors{}\gdef\tutors{}
\def \image#1{\@namedef {\role@\l@Arg.{\role@.id}.image}{#1}}%
\def \imageurl#1{\@namedef {\role@.\csname\role@.id\endcsname.imageurl}{#1}}%
\def \imageauthor{\futurelet\next\imageauthor@}%
\def \imageauthor@{\ifx\next[\expandafter\image@author@@\else\expandafter\image@author@\fi}%
\def \image@author@#1{\@namedef {\role@.\csname\role@.id\endcsname.imageauthor}{\textcolor{verbatimnumbers}{#1}}}%
\def \image@author@@[#1]#2{\@namedef {\role@.\csname\role@.id\endcsname.imageauthor}{\href{#1}{\textcolor{verbatimnumbers}{#2}}}}%
\def \theemail#1{\@namedef {\role@\l@Arg.{\role@.id}.email}{#1}\egroup}%
\def\email{\bgroup\catcode`\_=12 \catcode`\%=12 \catcode`\$=12 \catcode`\&=12 \catcode`\"=12 \catcode`\^=12
    \global\theemail}
    \long\def\info#1{\long\l@Arg\def{\role@.\csname\languagename-\role@.id\endcsname.info}{#1}}
\new@l@data@{thanks}
\expandafter\def\expandafter\do@thanks\expandafter#\expandafter1\expandafter{\thanks{#1}\catcode`_=8 }
\def \thanks{\catcode`_=12 \do@thanks}
\new@l@data@{address}
\renewcommand{\title}[2][]{%
    \expandafter\setlang\csname\languagename-\endcsname
    \@ifnotempty{#2}{\l@Arg\def{title}{#2}\l@Arg\def{shorttitle}{#2}}%
    \@ifnotempty{#1}{\l@Arg\def{shorttitle}{#1}}}%
\def\shortauthors#1{\l@Arg\def{shortauthorsShorted}{#1}\l@Arg\def{FshortauthorsShorted}{#1}}
\def\person@#1#2#3{% #1=Class #2-Short #3-Names
    \xdef\role@{#1}%
    \expandafter\l@casenew\csname\languagename-#1=\detokenize{#3}\endcsname{#3}{#1}%
    \@ifundefined{#1.id}{%
    \@namedef{#1.id}{1}}{%
        \ifnum\numexpr\l@nameuse{#1.id}>\numexpr\@nameuse{#1.id}\expandafter
        \let\csname #1.id\expandafter\endcsname\csname\languagename-#1.id\endcsname\fi}%
    \expandafter\@extract@initials@\csname\languagename-#1.\l@nameuse{#1.id}.initials\endcsname#3, , ,\@nil
    \expandafter\@extract@firstname@\csname\languagename-#1.\l@nameuse{#1.id}.first\endcsname#3, , ,\@nil
        \expandafter\def\csname\languagename-Fshort#1.\l@nameuse{#1.id}\expandafter\expandafter\expandafter
            \endcsname\expandafter\expandafter\expandafter{\csname
            \ifnum\language=\l@russian cyr\else lat\fi @#1\expandafter\endcsname
            \csname\languagename-#1.\l@nameuse{#1.id}.initials\expandafter\endcsname
            \csname\languagename-#1.\l@nameuse{#1.id}.first\expandafter\endcsname#3, , ,\@nil}%
        \expandafter\def\csname\languagename-short#1.\l@nameuse{#1.id}\expandafter\expandafter\expandafter
            \endcsname\expandafter\expandafter\expandafter{\csname
            cyr@#1\expandafter\endcsname
            \csname\languagename-#1.\l@nameuse{#1.id}.initials\expandafter\endcsname
            \csname\languagename-#1.\l@nameuse{#1.id}.first\expandafter\endcsname#3, , ,\@nil}%
%\@ifempty{#2}{}{\l@Arg\def{Fshort#1.\l@nameuse{#1.id}}{#2}}%
    \l@Arg\def{#1.\l@nameuse{#1.id}}{#3}%
    \l@ifundefined{short#1s}{\expandafter\def\csname \languagename-short#1s\expandafter\endcsname
    \expandafter{\csname\languagename-short#1.\l@nameuse{#1.id}\endcsname}   
    }{%
    \expandafter\g@addto@macro\csname \languagename-short#1s\expandafter\endcsname
    \expandafter{\expandafter,\expandafter\space
    \csname\languagename-short#1.\l@nameuse{#1.id}\endcsname}}%
    \l@ifundefined{Fshort#1s}{\expandafter\def\csname \languagename-Fshort#1s\expandafter\endcsname
    \expandafter{\csname\languagename-Fshort#1.\l@nameuse{#1.id}\endcsname}   
    }{%
    \expandafter\g@addto@macro\csname \languagename-Fshort#1s\expandafter\endcsname
    \expandafter{\expandafter,\expandafter\space
    \csname\languagename-Fshort#1.\l@nameuse{#1.id}\endcsname}}%
    \expandafter\let\csname\languagename-short#1sShorted\expandafter\endcsname\csname\languagename-short#1s\endcsname  
    \expandafter\let\csname\languagename-Fshort#1sShorted\expandafter\endcsname\csname\languagename-Fshort#1s\endcsname  
    \langshow{#1.\l@nameuse{#1.id}}%
    \langshow{Fshort#1.\l@nameuse{#1.id}}
    \langshow{Fshort#1s}%
    \langshow{short#1.\l@nameuse{#1.id}}
    \langshow{short#1s}%
    }
    % 
\newcounter{pstadata}
\def\set@person@loop#1#2{% #1-action
    \setcounter{pstadata}\z@
    \def\person@body{\stepcounter{pstadata}%
    \ifnum\c@pstadata > \l@nameuse{#1.id}\else#2\expandafter\person@body\fi}}%
\renewcommand{\author}[2][]{\person@{author}{#1}{#2}}%
\edef\tutor{\@nx\@dblarg\@xp\@nx\csname\string\tutor\endcsname}%
\def\@extract@initials@#1#2,#3,#4\@nil{\@extract@initials{#3}{\edef\@tempa{\def\@nx#1{\@tempa}}}}
\def\@extract@firstname@#1#2,#3#4,#5\@nil{\ifx#3\space \@extract@firstname#1#4 ,\else\@extract@firstname#1#3#4 ,\fi}
\def\@extract@firstname#1#2 #3,{\def#1{#2}}
\renewcommand{\tutor}[2][]{\person@{tutor}{#1}{#2}}%
\def\cyr@author#1#2#3,#4\@nil{#1~#3}%
\def\cyr@tutor#1#2#3,#4,#5,#6,#7\@nil{\textit{#6}&#1&#3 #5\cr}%
\def\lat@author#1#2#3,#4\@nil{#2~#3}%
\let\lat@tutor\lat@author
%
%\def\@firstofthree#1#2#3{#1}
%\def\@secondofthree#1#2#3{#2}
%\def\@thirdofthree#1#2#3{#3}
\def\submittedby#1{\def\submitted@by{#1}}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%% format thanks, info, image
\def\pstavvvvvvvvvvvvvvvvv{\vskip3mm plus5mm minus1mm }
\def\pstaVVVVVVVVVVVVVVVVV{\vskip4mm plus8mm minus2mm \pagebreak[1]}
\def\pstaVVVVVVVVVVVVVVVVV@{\vskip10mm plus20mm minus5mm \pagebreak[2]}
\def\swap@fio#1,#2\endswap@fio{#2 #1}
\def\format@info#1{\noindent\small \hfil\textbf{{}\expandafter\expandafter\expandafter
    \swap@fio\csname\languagename-#1\endcsname\endswap@fio}%
    \vadjust{\vskip2pt}\newline
    \@ifundefined{\languagename-#1.info}{\l@nameuse{#1.address}}%
        {\l@nameuse{#1.info}}%
    \par\smallskip\noindent\textsf{\itshape e-mail: }\hskip4ptplus.2\hsize$ $\penalty-3000
$ $\hskip4ptplus.2\hsize\href{mailto:\@nameuse{#1.email}}{\@nameuse{#1.email}}{\parfillskip\z@\@@par}}
\def\includeauthorgraphics#1{\leavevmode\llap{\rotatebox{90}{\rlap{\scalebox{.5}{\vbox{\hsize2\hsize\noindent\Large\textsf{#1}\@@par\vskip3mm}}}}}}
\def\set@author@info#1{\par\nobreak
    \@ifundefined{author.#1.image}%
        {\noindent\leavevmode\format@info{author.#1}{\parfillskip\z@\@@par}}%
        {\hbox to \hsize{\hss    
            $\vcenter{\hbox{%
               \@ifundefined{author.#1.imageauthor}{}{
                \includeauthorgraphics{\csname author.#1.imageauthor\endcsname}}
                {\expandafter\@secondfirstoftwo\expandafter
                    {\expandafter{\csname author.#1.image\endcsname}}%
                    {\includegraphics[width=2cm]}%
        }}}\hskip2mm
         \vcenter{\vbox{\advance\hsize-22mm\null\format@info{author.#1}{\parfillskip\z@\@@par}}}$\hss}}%
      \pstaVVVVVVVVVVVVVVVVV}  
\def\set@thanks@address{%
    \@footnotetext{{\let\par\@par\vskip -8pt\baselineskip 9pt\interlinepenalty\@M
        \rightskip0ptplus1cm
        \scriptsize
        \l@nameuse{thanks-s.list}%
        \vskip1ex
        \@par\tiny\scshape\parindent\z@\relax
        \format@address{\l@nameuse{author-s.list}}%
        \l@nameuse{address-s.list}\expandafter
        \ifx\csname \languagename-address=\expandafter\detokenize\expandafter{\LinkToHomepage}\endcsname\relax
        \format@address{\LinkToHomepage}\fi}}}
\def\format@thanks#1{\@par#1.}%
\def\format@address#1{\noindent{\tiny\copyright\quad\ignorespaces#1,\hskip1emminus1em \Year}\@@par}
\@namedef{thanks-format}#1{\format@thanks
    {\l@nameuse{thanks.#1}\l@ifundefined{authors-with-thanks.#1.list}{}{\ifnum
        \l@nameuse{thanks.id}> 1 \authorsmark{\l@nameuse{authors-with-thanks.#1.list}}\fi}}}
\@namedef{address-format}#1{\format@address
    {\l@nameuse{address.#1}\l@ifundefined{authors-with-address.#1.list}{}{\ifnum
\l@nameuse{address.id}>1 \authorsmark{\l@nameuse{authors-with-address.#1.list}}\fi}}}
\@namedef{author-format}#1{\l@nameuse{shortauthor.#1}%
    \ifnum \l@nameuse{address.id}>1 \authorsmark{#1}\else
    \l@ifundefined{thanks.id}{}{\ifnum \l@nameuse{thanks.id} >1 \authorsmark{#1}\fi}\fi}%
\@namedef{author-join}{, }%
\@namedef{thanks-of-author-join}{, }%
\@namedef{address-of-author-join}{, }%
\def\authorsmark#1{\ifnum \l@nameuse{author.id}>1 \raise.7ex\hbox{\scalebox{0.4}{\textcolor
    {authorsmarks}{{\small(\normalsize\textsf{#1}\small)}}}}\!\!\fi}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%% keywords related
\def\keywords#1{\l@Arg\def {keywords}{#1}}
\def\@setkeywords{\vskip3ptplus2pt
    {\noindent\footnotesize\itshape \keywordsname:}\enspace 
    {\scriptsize\textsf{\l@nameuse{keywords}.}\par}}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%% abstract related
\def\@abstractenvname{abstract}%
\long\def\abstract#1\end{\endgroup\long\global\l@Arg\def{abstract}{#1}
           \begingroup \def \@currenvir{abstract}\@endpefalse
        \end}%
\let\endabstract\@empty
\def\headlinelanguage#1{{\expandafter\selectlanguage\expandafter{\document@language}#1}}
\let\virtualpunct.
\def\@ifother@language#1#2{\begingroup\edef\languagename{#1}
    \ifnum \csname l@\languagename\endcsname=\csname l@\document@language\endcsname\else
    \selectlanguage{#1}#2\endgroup\fi}%
\def\@set@resume{%
    \let\@makefnmark\relax  \let\@thefnmark\relax
    \small
    \@ifrus{\l@nameuse{setsubjclasses}\par
        \pstavvvvvvvvvvvvvvvvv
    \small}{}\set@thanks@address
    \setbox\abstractbox\vbox{\footnotesize
        \l@ifundefined{Fshortauthors}{}{\l@nameuse{Fshortauthors}. }% 
    \textit{\l@nameuse{title}}.
    \@ifundefined{\languagename-abstract}{}
    {\SMALL\list{}{\labelwidth\z@
      \leftmargin1em \rightmargin\leftmargin
      \listparindent\normalparindent \itemindent\z@
      \parsep\z@ \@plus\p@
      \let\fullwidthdisplay\relax}
    \item[\hskip\labelsep\scshape\abstractname.]%
        \l@nameuse{abstract}\endlist}
     }\box\abstractbox
     \l@ifundefined{keywords}{}{\@setkeywords}
     \penalty\@M
     \@ifrus{}{
          \pstavvvvvvvvvvvvvvvvv
     \l@nameuse{setsubjclasses}}
     \@@par}
\newif\iftransbibliography     
\def\@set@ssylka{%
    \expandafter\ifx\csname \languagename-title\endcsname\relax\else
    \pstaVVVVVVVVVVVVVVVVV
    \let\virtualpunct\relax
     \noindent\textit{\SSylkaa}\@@par\nobreak\vskip 1mmplus2mm
        \spaceskip3ptplus2ptminus1pt
        \l@ifundefined{Fshortauthors}{}{\l@nameuse{FshortauthorsShorted}%
            \expandafter\ifx
                \csname \languagename -Fshortauthors\expandafter\endcsname
                \csname \languagename -shortauthorsShorted\endcsname\fi
             . } \startquote\l@nameuse{title}\stopquote 
        \if\PSTAforUGP {. \textit{{\conf@name  \numberofConf{} \conf@name@} 
        \hbox{SIT-\PSTAyear}}. \UGP. --- \placename{}: 
            \izd@vo@ugp, \number\Year}
            \else, \textit{\fullPSTA}, \Year, \textbf{\Volume}:\Numissue, \fi
            \bibpagestext~\expandafter\formatPagerange\expandafter{\pagerange}. (\emph \LngName).
        \hskip1ptplus.5\hsize\vrule width -1sp height 0pt depth6pt $ $\penalty-3000
                {\scriptsize \textsf{URL}:}\hskip3ptplus2\hsize
                \url{\pstaurl}{\parfillskip\z@\rightskip\z@\@@par}\let\virtualpunct.
  \fi}
\def\submittedby@autorsinfo@resume{\@ifresume{
     \makesubmittedby
    \pstavvvvvvvvvvvvvvvvv
    \makepstaQ\pagebreak[1]\makessylka
    \pstaVVVVVVVVVVVVVVVVV
    \makeautorsinfo
    \@ifother@language{russian}{
      \pstaVVVVVVVVVVVVVVVVV@
      \@set@resume\bib@set@cyr\@set@ssylka}%
      \csname BeforeEnglishInfo \endcsname
    \@ifother@language{english}{
      \pstaVVVVVVVVVVVVVVVVV@
      \@set@resume}%
  }{}}  
\def\enddoc@text{\@ifundefined{UGP@referat}{%
     \null\par\@fileswtrue\iftransbibliography\endgroup\else\submittedby@autorsinfo@resume\fi
    \@ifresume{\@ifother@language{english}{\bib@set@lat\@set@ssylka}}{} 
    \pstaVVVVVVVVVVVVVVVVV@
    \pstaVVVVVVVVVVVVVVVVV@
    \pstaVVVVVVVVVVVVVVVVV@
    \break}{}}
\def\BeforeEnglishInfo#1{\expandafter\gdef\csname BeforeEnglishInfo \endcsname{#1}}
\def\BeforeEnglishRefs#1{\expandafter\gdef\csname BeforeEnglishRefs \endcsname{#1}}
\BeforeEnglishRefs{\pstaVVVVVVVVVVVVVVVVV}
\def\transbibliography#1{\thebibliographyinEnglish#1}
\def\thebibliographyinEnglish{\transbibliographytrue\submittedby@autorsinfo@resume
    \csname BeforeEnglishRefs \endcsname
\footnotesize \theenglishbibliography}
\def\makesubmittedby{
        \let\\\space
    \ifx\UndefIned\submitted@by\else{
        \vskip1mm \noindent\leavevmode
        {\small\Predstavil}\hskip 1emplus500cm
        \textit{\submitted@by}\leftskip0ptplus5cm
        \parfillskip0pt\@@par}\fi
        {\expandafter\ifx\csname\languagename footnotetexttosection\endcsname\relax\else
        \scriptsize
            \vskip1mm plus1cm minus 1mm
        \parindent -1em {\textbf\Submittedwithname: 
        {\csname\languagename footnotetexttosection\endcsname\unskip\allowhyphens.}}
        \baselineskip8pt\leftskip1em\@@par \fi}\let\makesubmittedby\relax}
\def\makeautorsinfo{
    \l@ifundefined{tutor.id}{}{
        \ifcase \@nameuse{tutor.id}\or \advisorname: \set@tutors\else\advisorsname: \set@tutors\fi}%
        \set@person@loop{author}{\set@author@info{\arabic{pstadata}}}{}
       % \show\person@body
        \l@ifundefined{author.id}{}%
        {
            \vskip1mm plus1cm minus1mm\pagebreak[3]
            \noindent\textit{\ifcase\l@nameuse{author.id}\or\oneauthor:\else\manyauthors:\fi}
            \nobreak\vskip1mm plus1cm minus1mm      
    \person@body \par}\let\makeautorsinfo\relax}  
\def\DoResume{\global\let\@ifresume\@firstoftwo \wlog{Resume On}}
\def\NoResume{\global\let\@ifresume\@secondoftwo \wlog{Resume Off}}\NoResume

\def\set@tutors{\par
    \hbox to \hsize{\hss\vbox{\baselineskip14pt\halign{\hskip 3cm##\hfil&\quad\hfil##&~##\cr
        \l@nameuse{shorttutors}}\vskip2mmplus3cm\pagebreak[1]}}}
\def\makessylka{\spaceskip3ptplus8ptminus2pt
        \noindent\textit{\SSylkaa}\@@par\nobreak\vskip 1mmplus3mm
        \small\spaceskip3ptplus3ptminus2pt\let\virtualpunct\relax
        \l@ifundefined{shortauthorsShorted}{}{\l@nameuse{shortauthorsShorted}%
            \expandafter\ifx
                \csname \languagename -shortauthors\expandafter\endcsname
                \csname \languagename -shortauthorsShorted\endcsname \fi
            . }\startquote\l@nameuse{title}\stopquote 
        \if\PSTAforUGP {. \textit{\conf@name  \numberofConf{} \conf@name@} 
            \hbox{SIT-\PSTAyear}. \UGP. --- \placename{}: 
            \izd@vo@ugp, \number\Year}
            \else, \textit{\fullPSTA}, \Year, \textbf{\Volume}:\Numissue, \fi
        \bibpagestext~\expandafter\formatPagerange\expandafter{\pagerange}.\let\virtualpunct.
        \hskip1ptplus.5\hsize\vrule width -1sp height 0pt depth6pt $ $\penalty-3000 
        {\scriptsize \textsf{URL}:}\hskip3ptplus2\hsize
    \url{\pstaurl}{\parfillskip\z@\rightskip\z@\@@par}\let\makessylka\relax}
\def\makepstaQ{
    \expandafter\ifx\csname psta-Q\endcsname\relax\else
    \bigskip\par%\noindent
    \textbf{{\itshape \PSTAjouQ\/}:}
    \csname psta-Q\endcsname\fi
    \expandafter\ifx\csname psta-A\endcsname\relax\else
    \par\textbf{{\itshape \PSTAjouA\/}:}
    \csname psta-A\endcsname \vfill\fi
    \bigskip\small\par\bgroup
    \expandafter\ifx\csname psta-In\endcsname\relax\else
    \textit{\Postupila}
    \csname psta-In\endcsname.\fi
    \egroup}

%\def\otherlanguagebreak{\vskip3cmplus5cm\penalty-10000}
%\def\mixedlanguagepage{\let\otherlanguagebreak\relax}


\@ifundefined{IfInclude}{\def\IfInclude#1#2{#2}}{}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%% maketitle
\def\maketitle{\par
    \@namedef{pdf-abstract}{\expandafter\expandafter\expandafter\detokenize
    \expandafter\expandafter\expandafter{\csname english-abstract\endcsname}}
    \expandafter\let\expandafter\shorttitle\csname\languagename-shorttitle\endcsname
    \@topnum\z@ % this prevents figures from falling at the top of page 1
    \thispagestyle{firstpage}% this sets first page specifications
    \begingroup \@maketitle
        \endgroup% ending (after addresses)
    \let \par\space
    \hypersetup{unicode=true,
        pdfkeywords={\csname english-keywords\endcsname},
        pdftitle={\csname english-title\endcsname},
        pdfauthor={\csname english-Fshortauthors\endcsname},
        pdfsubject={\csname pdf-abstract\endcsname}}
    \let\par\@@par
    \c@footnote\z@
   \l@Arg\ifx{shortauthors}\relax
    \markboth{\protect\pstarightline}{\protect\pstarightline}\else
    \markboth{\protect\pstaleftline}{\protect\pstarightline}\fi}
{\catcode`\#=12 \xdef\hashmark{#}} 
\IfInclude{%
    \gdef\pstarightline{\hyperlink{\languagename contents}{\headlinelanguage{\l@nameuse{shorttitle}}}}%
    \gdef\pstaleftline{\hyperlink{\languagename index}{\headlinelanguage{\l@nameuse{FshortauthorsShorted}}}}}{%
    \gdef\pstarightline{\href{\pstaurl\hashmark\languagename contents}{\headlinelanguage{\l@nameuse{shorttitle}}}}%
    \gdef\pstaleftline{\href{\pstaurl\hashmark\languagename index}{\headlinelanguage{\l@nameuse{FshortauthorsShorted}}}}}%
%\def\short@author#1{\l@nameuse{#1.shortauthor}}
\def\displaysubtitle{\\[1ptplus1pt] \large}
\def\inlinesubtitle{\unskip. }\let\subtitle\inlinesubtitle
\def\@maketitle{% inside group
  \normalfont\normalsize
  \null\vskip-14pt
  \let\@makefnmark\relax  \let\@thefnmark\relax
\@ifrus{\l@nameuse{setsubjclasses}}{}
  \set@thanks@address
  \global\topskip0pc\relax % 10pc to base of first title line
  \expandafter\begingroup\trivlist
      \centering \fontsize{11}{13\p@}\selectfont\@topsep13\p@\relax
      \item\relax
      \def\\{\protect\linebreak}%
      \l@nameuse{shortauthors}%
      \endtrivlist\endgroup
  \l@ifundefined{title}{}{%
        \begin{center}%
             \let\subtitle\displaysubtitle   
             \Large\bfseries
             \l@nameuse{title}
        \end{center}}
  \ifx\@empty\@dedicatory
  \else
    \baselineskip26\p@
    \vtop{\centering{\footnotesize\itshape\@dedicatory\@@par}%
      \global\dimen@i\prevdepth}\prevdepth\dimen@i
  \fi
  \vskip0ptplus6pt
  \l@ifundefined{abstract}{}{%
        \skip@20\p@ \advance\skip@-\lastskip
        \advance\skip@-\baselineskip \vskip\skip@
        \setbox\abstractbox=\vtop {\normalfont\Small
        \list{}{\labelwidth\z@
        \leftmargin1pc \rightmargin\leftmargin
        \listparindent\normalparindent \itemindent\z@
        \parsep\z@ \@plus\p@
        \let\fullwidthdisplay\relax}
        \item[\hskip\labelsep\scshape\abstractname.]%
        \l@nameuse{abstract}\endlist}\box\abstractbox
        \prevdepth\z@}
  \normalsize
  \l@ifundefined{keywords}{}{\@setkeywords}
     \@ifrus{}{\vskip 3ptplus3ptminus2pt\l@nameuse{setsubjclasses}}
  \if@titlepage
    \newpage
  \else
    \dimen@20\p@ \advance\dimen@-\baselineskip
    \vskip\dimen@\relax
  \fi
  \let\subtitle\inlinesubtitle
  \DoResume} % end \@maketitle%


%%
%% 3. Sectioning 
%%
\def\section{\@startsection{section}{1}%
  \normalparindent{.7\linespacing\@plus\linespacing}{.5\linespacing}%
  {\normalfont\sffamily\bfseries\raggedright}}
\def\subsection{\@startsection{subsection}{2}%
  \normalparindent{.5\linespacing\@plus.7\linespacing}{.4\linespacing}%
  {\normalfont\sffamily\bfseries\raggedright}}
\def\subsubsection{\@startsection{subsubsection}{3}%
  \normalparindent{.3\linespacing\@plus.5\linespacing}{.3\linespacing}%
  {\normalfont\sffamily\itshape\raggedright}}
\def\paragraph{\@startsection{paragraph}{4}%
  \normalparindent{.2\linespacing\@plus.3\linespacing}{.2\linespacing}%
  {\normalfont\sffamily\raggedright}}
\def\subparagraph{\@startsection{subparagraph}{5}%
  \z@{.5\linespacing}{-\fontdimen2\font\raggedright}%
  {\normalfont\sffamily}}
\def\@part[#1]#2{%
  \ifnum \c@secnumdepth >-2\relax \refstepcounter{part}%
    \addcontentsline{toc}{part}{\partname\ \thepart.
        \protect\enspace\protect\noindent#1}%
  \else
    \addcontentsline{toc:}{part}{#1}\fi
  \begingroup\raggedright
  \ifnum \c@secnumdepth >-2\relax
       {\sffamily\fontsize{\@xviipt}{22}\bfseries
         \partname\ \thepart} \vskip 20\p@ \fi
  \fontsize{\@xxpt}{25}\sffamily\bfseries
      #1\vfil\vfil\endgroup \newpage\thispagestyle{empty}}
\def\@makechapterhead#1{\global\topskip 7.5pc\relax
  \begingroup
  \fontsize{\@xivpt}{18}\sffamily\bfseries\raggedright
    \ifnum\c@secnumdepth>\m@ne
      \leavevmode \hskip-\leftskip
      \rlap{\vbox to\z@{\vss
          \hbox{\hskip\normalparindent\normalsize\sffamily\mdseries
              \MakeTextUppercase\@xp{\chaptername}\enspace\thechapter}
          \vskip 3pc}}\hskip\leftskip\fi
     \hskip\normalparindent#1\par \endgroup
  \skip@34\p@ \advance\skip@-\normalbaselineskip
  \vskip\skip@ }
\def\@makeschapterhead#1{\global\topskip 7.5pc\relax
  \begingroup
  \fontsize{\@xivpt}{18}\sffamily\bfseries\raggedright
  #1\par \endgroup
  \skip@34\p@ \advance\skip@-\normalbaselineskip
  \vskip\skip@ }
\def\appendix{\par
  \c@chapter\z@ \c@section\z@
  \let\chaptername\appendixname
  \def\thechapter{\@Alph\c@chapter}}
%%
%% 3. Lists 
%%
\def\@listI{\leftmargin\leftmargini \parsep\z@skip
  \topsep\listisep \itemsep\z@skip
  \listparindent\normalparindent}
\let\@listi\@listI
\def\@listii{\leftmargin\leftmarginii
  \labelwidth\leftmarginii \advance\labelwidth-\labelsep
  \topsep\z@skip \parsep\z@skip \partopsep\z@skip \itemsep\z@skip}
\def\@listiii{\leftmargin\leftmarginiii
  \labelwidth\leftmarginiii \advance\labelwidth-\labelsep}
\def\@listiv{\leftmargin\leftmarginiv
  \labelwidth\leftmarginiv \advance\labelwidth-\labelsep}
\def\@listv{\leftmargin\leftmarginv
  \labelwidth\leftmarginv \advance\labelwidth-\labelsep}
\def\@listvi{\leftmargin\leftmarginvi
  \labelwidth\leftmarginvi \advance\labelwidth-\labelsep}
\newskip\listisep
\listisep\smallskipamount
\def\@listIZ{\leftmargin18pt \parsep=.5\smallskipamount 
  \topsep2\parsep \itemsep\z@skip  \listparindent\normalparindent}
\AtBeginDocument{\leftmargini=2em
\leftmarginii=1.7em
\leftmarginiii=1.6em
\def\labelenumi{{\upshape\footnotesize
\textsf{(\emph{\theenumi})\!}}}
\def\labelitemi{{$\m@th\scriptstyle
        \bullet$}}}
\renewenvironment{quotation}{\list{}{%
    \leftmargin\parindent \listparindent\normalparindent
    \itemindent\parindent
    \rightmargin\leftmargin \parsep\z@ \@plus\p@}%
  \item[]%
}{%
  \endlist
}

%%
%% 5. Russian punctuation 
%%

\renewenvironment{biblist}[1][]{%
  \normalfont \footnotesize \labelsep .5em\relax
  \list{\BibLabel}{%
    \resetbiblist{00}%
    \usecounter{bib}%
    #1\relax
  }%
  \sloppy
  \interlinepenalty\@m  \clubpenalty\@M \widowpenalty\clubpenalty
  \frenchspacing\parskip1ptplus1ptminus.5pt
  \ResetCapSFCodes
  \let\@bibdef\normal@bibdef
}{%
  \def\@noitemerr{\@latex@warning{Empty bibliography list}}%
  \endlist
}

\if\fancyload
\RequirePackage{fancyvrb}
\renewcommand{\theFancyVerbLine}{{\textcolor{verbatimnumbers}{\tiny\itshape\textbf{\arabic{FancyVerbLine}}}}}
%
\if \mintedload
\RequirePackage{minted}
\newcommand{\minted@write@detok}[1]{%
  \immediate\write\FV@OutFile{\detokenize{#1}}}%
\newcommand{\minted@FVB@VerbatimOut}[1]{%
  \@bsphack
  \begingroup
    \FV@UseKeyValues
    \FV@DefineWhiteSpace
    \def\FV@Space{\space}%
    \FV@DefineTabOut
    \let\FV@ProcessLine\minted@write@detok %Patch for Unicode
    \immediate\openout\FV@OutFile #1\relax
    \let\FV@FontScanPrep\relax
    \let\@noligs\relax
    \FV@Scan}
    \let\FVB@VerbatimOut\minted@FVB@VerbatimOut
\renewcommand\minted@savecode[1]{
  \immediate\openout\minted@code\jobname.pyg
  \immediate\write\minted@code{\expandafter\detokenize\expandafter{#1}}%
  \immediate\closeout\minted@code} %% end of patch
\fi 
\AtBeginDocument{\FancyVerts}
\fi
%
\def\blacklbrace{\textcolor{black}{\textup\textbraceleft}}
\def\blackrbrace{\textcolor{black}{\textup\textbraceright}}
\def\blacklparent{\textcolor{black}{\textup(}}
\def\blackrparent{\textcolor{black}{\textup)}}
\def\blacklbraket{\textcolor{black}{\textup[}}
\def\blackrbraket{\textcolor{black}{\textup]}}
\def\HighliteSlash{\textcolor{gt}{\string/}}
\def\HighliteGt{\textcolor{gt}{\string>}}
\let\PSTAverbvert\PSTAverbVert
\def\PSTAverbVert{\bgroup\PSTAverbBcatcodes \PSTAverbvert@}
\let\textpstaverbfont\textsf
\let\textpstaverbsize\footnotesize
\def\setbsbs{\edef\\{\char 92 }}
\def\PSTAverbvert@box#1{\texorpdfstring{\scalebox{1.15}{\textpstaverbsize\textpstaverbfont{\pstaVerbCommon{#1}}}}{#1}}
\def\HighlightEnvironment#1#2{\DefinePSTAVerbatimEnvironment{#1}{Verbatim}{fontsize=\textpstaverbsize,
    frame=lines,framerule=.25mm,framesep=2mm,rulecolor=\color{verbatimrules},
    label={\tiny \textcolor{verbatimtitle}{\itshape\textpstaverbfont{#2}}},labelposition=topline,fillcolor=\color{verbatimtitle},
    numbers=left,numbersep=5pt,gobble=0, commandchars=\\\{\},
    formatcom={\PSTAverbBcatcodes\setbsbs\let\PSTAverbvert@box\pstaVerbCommon
    \color{verbatimdefault}}}\FancyVerts}
\def\HighlightXMLEnvironment#1#2{\DefinePSTAVerbatimEnvironment{#1}{Verbatim}{fontsize=\textpstaverbsize,
    frame=lines,framerule=.25mm,framesep=2mm,rulecolor=\color{verbatimrules},
    label={\tiny \textcolor{verbatimtitle}{\itshape\textpstaverbfont{#2}}},labelposition=topline,fillcolor=\color{verbatimtitle},
    numbers=left,numbersep=5pt,gobble=0, commandchars=\\\{\},codes={\catcode`/=13  \catcode`==13 \catcode `$=3 },
    formatcom={\PSTAverbBcatcodes\setbsbs\let\PSTAverbvert@box\pstaVerbCommon\color{verbatimdefault}\XMLgt}}\FancyVerts}
\def\HighlightMathEnvironment#1#2{\DefinePSTAVerbatimEnvironment{#1}{Verbatim}{fontsize=\textpstaverbsize,
    frame=lines,framerule=.25mm,framesep=2mm,rulecolor=\color{verbatimrules},
    label={\tiny \textcolor{verbatimtitle}{\itshape\textpstaverbfont{#2}}},labelposition=topline,fillcolor=\color{verbatimtitle},
    numbers=left,numbersep=5pt,gobble=0,commandchars=\\\{\},codes={\catcode`$=3\catcode`_=8\catcode`^=7},formatcom={\let\PSTAverbvert@box\pstaVerbCommon
    \color{verbatimdefault}}}\FancyVerts}
\catcode`\)=13 \catcode`\(=13 \catcode`\]=13 \catcode`\[=13 \catcode`\|=13 
\def\PSTAverbvert@#1|{\PSTAverbvert@box{#1}\egroup}    
\def\PSTAverbBcatcodes{\catcode`\#=12 \catcode`\^=12 \catcode`\&=12 \catcode`\_=12 \catcode`\%=12 \catcode`\$=12 
\catcode`\]=13 \catcode`\[=13 \catcode`\)=13 \catcode`\(=13 \catcode`\|=13 
\let[\blacklbraket\let]\blackrbraket\let(\blacklparent\let)\blackrparent \let|=\PSTAverbVert
\let\{\blacklbrace\let\}\blackrbrace}
\def\HighliteAlso#1{\g@addto@macro\PSTAverbBcatcodes{#1}}
\def\FancyVert{\bgroup\PSTAverbBcatcodes \PSTAverbvert@}
\def\FancyVerts{\catcode`|=13 \let |=\PSTAverbVert}
\def\OtherVerts{\catcode`|=12 }
\catcode`/=13 
\def\HighliteLt#1{\textcolor{gt}{<}\ifx/#1\expandafter\HighliteLt@\else\expandafter\HighliteLt@@\fi#1}
\def\HighliteLt@#1\>{\textcolor{key}{#1}\HighliteGt}
\catcode32=13 \def\HighliteLt@@#1 {\textcolor{key}{#1} }\catcode32=10
\catcode`"12 
\def\XMLeq"#1"{\textcolor{gt}{\string=\string"\textcolor{key}{#1}\string"}}
\catcode`==13
\def\XMLgt{\let\> \HighliteGt \let\< \HighliteLt \let=\XMLeq \let/\HighliteSlash}
\catcode`=12 \catcode`/=12 \catcode`\)=12 \catcode`\(=12 \catcode`\]=12 \catcode`\[=12 \catcode`|=12 
\def\pstaVerbCommon#1{\@ifundefined{psta-Verb\detokenize{#1}}%
    {\expandafter\pstaVerbtestfirstchar\string#1\endpstaVerb#1\endpstaVerb}%
    {\@nameuse{psta-Verb\detokenize{#1}}}}
    \def\kwdef#1#2{\@namedef{psta-Verb\detokenize{#1}}}
\def\pstaVerbtestfirstchar#1#2\endpstaVerb{\@ifundefined{\string#1pstaVerb}{\pstaVerb}{\@nameuse{\string#1pstaVerb}}}
\@namedef{\string $pstaVerb}#1\endpstaVerb{\textcolor{variable}{\textpstaverbfont{\string #1}}}
\@namedef{\string @pstaVerb}#1\endpstaVerb{\textcolor{variable}{\textpstaverbfont{\string #1}}}
\@namedef{\string "pstaVerb}#1\endpstaVerb{\textcolor{string}{\textpstaverbfont{\string #1}}}
\@namedef{\expandafter\@gobble\string \{pstaVerb}#1\endpstaVerb{\textcolor{string}{\textpstaverbfont{\textit{#1}}}}
\@namedef{\string \pstaVerb}#1\endpstaVerb{\textpstaverbfont{#1}}
\def\pstaVerb#1\endpstaVerb{\textcolor{word}{\textpstaverbfont{\string #1}}}%
\def\@firstoffour#1#2#3#4{#1}
\def\coloredkeyframe#1#2#3#4#5{{\setbox\@tempboxa\hbox{#5}%
    \@tempdima \wd\@tempboxa  
    \hbox{\hskip -1pt
        \@@key@ruled     {{#1}{#2}{0.3pt}}{1.00}{0.35}{0.40}{0.60}{0.7}{0.9}{#3}{#4}% 
        \@@key@ruled     {{#1}{#2}{0.3pt}}{0.050}{0.3}{0.33}{0.75}{0.85}{0.95}{#3}{#4}% 
        \@@key@ruled     {{#1}{#2}{0.3pt}}{0.025}{0.2}{0.27}{0.87}{0.90}{0.975}{#3}{#4}% 
        \@@key@ruled{{#1}{#2}{\@tempdima}}{0.000}{0.03}{0.10}{0.92}{0.95}{1}{#3}{#4}% 
        \@@key@ruled     {{#1}{#2}{0.3pt}}{0.025}{0.05}{0.27}{0.95}{0.97}{0.975}{#3}{#4}% 
        \@@key@ruled     {{#1}{#2}{0.3pt}}{0.050}{0.15}{0.33}{0.8}{0.94}{0.95}{#3}{#4}% 
        \@@key@ruled     {{#1}{#2}{0.3pt}}{1.00}{0.25}{0.40}{0.80}{0.89}{0.9}{#3}{#4}% 
    \hskip -1pt\hskip -\@tempdima \box\@tempboxa}}}
\def\@@key@ruled#1#2#3#4#5#6#7#8#9{%    \tracingall
    \@@key@rule{#8}#1{#2}{#3}1\@@key@rule{#9}#1{#3}{#4}1\@@key@rule{#9}#1{#5}{#6}1\@@key@rule{#8}#1{#6}{#7}0}
\def\@@key@rule#1#2#3#4#5#6#7{%
    \@tempdimc=#3\@tempdimc=#5\@tempdimc\advance\@tempdimc#2
    \@tempdimb=#3\@tempdimb=#6\@tempdimb\advance\@tempdimb#2
    \textcolor{#1}{\vrule width #4 depth-\@tempdimc height\@tempdimb}\if1#7\hskip-#4\fi}
    
\def\SyntaxBlack#1,#2{\@namedef{psta-Verb\detokenize{#1}}{\textcolor{black}{\fontfamily{\rmdefault}\textbf{#1}}}%
\if,#2\@firstoffour\fi\SyntaxBlack#2}
\def\pstaFormatTypedef#1{\@namedef{FormatType#1}##1}
\def\pstaFormatType#1#2,#3{\@namedef{psta-Verb\detokenize{#2}}{\@nameuse{FormatType#1}{#2}}%
    \if,#3\@firstoffour\fi\pstaFormatType{#1}#3}
\def\HighlightAs#1: #2.{\pstaFormatType{#1}#2,,\FancyVerts}
\def\SyntaxType#1#2,#3{\@namedef{psta-Verb\detokenize{#2}}{\textcolor{#1}{\textpstaverbfont{#2}}}%
    \if,#3\@firstoffour\fi\SyntaxType{#1}#3}
\def\Highlight#1: #2.{\SyntaxType{#1}#2,,\FancyVerts}
\def\HighlightBlack #1.{\SyntaxBlack#1,,\FancyVerts}
\def\FV@FrameLineWithLabel{\ht \z@ \@tempdimb \dp \z@ \@tempdimb \FancyVerbRuleColor \@tempdima 1.97\@tempdimc
    \@tempdimc0.03\@tempdimc {\vrule \@width \@tempdima \@height \FV@FrameRule \raise \@tempdimb \box \z@ 
     \vrule \@width \@tempdimc \@height \FV@FrameRule }}
\def\DefinePSTAVerbatimEnvironment #1#2#3{\@namedef {#1}{\pagebreak[3]\interlinepenalty 9000
    \FV@Environment {#3}{#2}}\@namedef {end#1}{\@nameuse {FVE@#2}}\@namedef 
    {#1*}{\FV@Environment {#3,showspaces}{#2}}\@namedef {end#1*}{\@nameuse {FVE@#2}\pagebreak[2]\interlinepenalty 100 }}
%
% Adds punctuation after code
\def\psta@verb@punct#1#2#3{\rlap{\hskip\textwidth\,\vbox to 0pt{\vss\hbox{\llap{\textcolor{white}{\vrule height 2ex width .5em depth.5ex}\llap{#1}}}#2}}#3}
\def\Add#1{\psta@verb@punct{#1}{\vskip .65\baselineskip}{\vskip -\baselineskip}}
\def\TAdd#1{\psta@verb@punct{#1}{}{}}
\def\finishwith#1{\ifx\saved@endparenv\UndEfinEd\global\let\saved@endparenv\@endparenv\fi\global\expandafter\let\expandafter\@endparenv\csname#1@endparenv\endcsname} 
\@namedef{ @endparenv}{\saved@endparenv}
\@namedef{.@endparenv}{\Add.\saved@endparenv\global\let\@endparenv\saved@endparenv}
\@namedef{,@endparenv}{\Add,\saved@endparenv\global\let\@endparenv\saved@endparenv}

\def\endthebibliography{\par\let\@noitemerr\@empty\endlist}

\gdef\backref#1{ \@ifresume{\hskip-2ptminus2pt\textcolor{backrefcolor}{$\uparrow\nobreak\hskip0ptminus4pt{}^{#1}$}}{}}

\def\thebibliography#1{%
    \def\@bibitem##1{\gdef\CurrentBib{\BR@backref{##1}}\@skiphyperreftrue \H@item \@skiphyperreffalse 
        \Hy@raisedlink {\hyper@anchorstart {cite.##1\@extra@b@citeb }\relax \hyper@anchorend }%
        \if@filesw \begingroup \let \protect \noexpand 
            \immediate \write \@auxout {\string \bibcite {##1}{{\the \value {\@listctr }}{}}\string
            \gdef \string \totalbibitems{\the \value {\@listctr }}}%
        \endgroup \fi  \misc@\ignorespaces} 
    \let\PSTAbibitem\bibitem
    \def\RBibitem{\par\defaultrusreftexts\BRorg@bibitem}
    \def\Bibitem{\par\defaultreftexts\BRorg@bibitem}
    \let\bibitem\RBibitem
    \refstepcounter{aux@counter}%
    \section*{\refname}
    \def\@biblabel##1{{[##1]}}
    \small
    \list
     {\@biblabel{\arabic{enumi}}}{\settowidth\labelwidth{\@biblabel{#1}}\leftmargin\labelwidth
         \advance\leftmargin\labelsep\usecounter{enumi}}%
     \baselineskip3.8mmplus1pt
     \parskip0.5ptplus1pt
     \def\newblock{\hskip .11em plus .33em minus .07em}%
     \def\allowbeak{\penalty\z@\hskip0ptplus2pt}%
     \clubpenalty4000\widowpenalty4000
     \sfcode`\.=1000\relax
     \def\makelabel##1{\hfil ##1}%
     \rightskip0ptplus1mm
     \spaceskip3ptplus8ptminus2pt}

\def\theenglishbibliography#1{\@fileswfalse\selectlanguage{english}\let\BR@backref\@gobble
    \def\smallerrefs{\global\let\elink@url@size\scriptsize\global\let\elinktext@size\tiny}%
    \def\normalrefs{\global\let\elink@url@size\footnotesize\global\let\elinktext@size\scriptsize}\normalrefs
    \refstepcounter{aux@counter}\def\@biblabel ##1{{[##1]}}%
    \def\@bibitem##1{\@skiphyperreftrue \par\H@item\misc@\ignorespaces}%
    \def\bibitem{\par\defaultreftexts\BRorg@bibitem}\let\Bibitem\bibitem
    \par\pagebreak[1]\noindent\textit{\refname }\Small 
    \list {\@biblabel {\arabic {enumi}}}{\settowidth\labelwidth{\@biblabel{#1}}\leftmargin  \labelwidth 
        \advance \leftmargin \labelsep \usecounter {enumi}} \parskip 0.5ptplus1pt
        \def \allowbeak {\penalty \z@ \hskip 0ptplus2pt}% 
        \clubpenalty 4000\widowpenalty 4000 \sfcode `\.=1000\relax 
        \def \makelabel ##1{\hfil ##1}\spaceskip 2.5ptplus8ptminus2pt 
        \rightskip0ptplus1mm}

\newcounter{aux@counter}

\newif\if@Ref@
\newif\if@finalpunct@ \@finalpunct@true
\newif\ifmoreref@
\newif\ifbook@
\newif\ifprocpaper@
\newif\if@kern

\def\test@Ref@{\if@Ref@\else\@@Ref\fi}

\def\@@Ref{\ifhmode\unskip\else\leavevmode\fi
  \begingroup \@Ref@true
  \def\envir@end{\end@@ref}%
  \let\par\end@@ref
  \global\let\nofrills@list\empty
  \refbreaks%
  \procpaper@false \book@false \moreref@false
  \def\curbox{\z@}\setbox\z@\vbox\bgroup}

\gdef\@ref{\@kernfalse
    \ifmoreref@ \commaunbox@AB@\translbox@AB@ 
    \else \@kerntrue 
    \fi 
    \if@kern\kern-\tw@ sp\kern\m@ne sp\fi \@@ref}

\def\defaultrusreftexts{\select@language{russian}\bib@set@russian \frenchspacing
    \gdef\openquote@AB@{<<}\gdef\closequote@AB@{>>}\global\@finalpunct@true}
\def\defaultreftexts{\bib@set@lat\select@language{english}\global\@finalpunct@true
    \gdef\openquote@AB@{``}\gdef\closequote@AB@{''}\frenchspacing}

\def\nofrills{\expandafter
    \ifx\envir@end\end@@ref \let\do\relax
        \xdef\nofrills@list{\nofrills@list\do\curbox}%
    \else\errmessage{\Invalid@@ \string\nofrills}\fi}%

\def\end@ref@{%
        \def\nofrillscheck##1{%
            \def\do####1{\ifx##1####1\let\frills@\@gobble\fi}%
        \let\frills@\@firstofone \nofrills@list}%
    \@ref}

\def\end@@ref{\makerefbox@AB@ \z@ {\egroup }\end@ref@\endgroup
    \keyhook@ \global \let \keyhook@ \empty}\let\keyhook@\empty

\def\refbreaks{%
    \let\volinfo\volinfo@AB@
    \let\refconcat\refconcat@AB@ 
    \let\vadjust\vadjust@AB@
    \let\newpage\newpage@AB@
    \let\newline\newline@AB@
    \let\linebreak\linebreak@AB@
    \def\holdover##1{\RIfM@\penalty -\@M\null\hfil$
            \clubpenalty\z@\widowpenalty\z@\interlinepenalty\z@ \offinterlineskip\@@par 
            \setbox\z@\lastbox\unskip \unpenalty \refconcat@AB@{##1}\noindent
            $\hfil\penalty -\@M
        \else {\parfillskip0pt \@@par}\refconcat@AB@{##1}\noindent
        \fi}}%

\def\makerefbox@AB@#1#2{\test@Ref@\@@par
  \setbox\z@\lastbox
  \global\setbox\@ne\hbox{\unhbox\holdoverbox
    \ifvoid\z@\else\unhbox\z@\unskip\unskip\unpenalty\fi}%
  \egroup
  \setbox\curbox\box\ifdim\wd\@ne>\z@ \@ne \else\voidb@x\fi
  \def\curbox{#1}\setbox#1\vbox\bgroup \hsize\maxdimen \noindent
  #2\leftskip\z@\relax}
\def\refconcat@AB@#1{\setbox\z@\lastbox \setbox\holdoverbox\hbox{%
    \unhbox\holdoverbox \unhbox\z@\unskip\unskip\unpenalty#1}}%
\def\@finalpunct{\if@finalpunct@.\fi
    \refquotes@\nobreak\CurrentBib\refbreak@AB@@}%
\def\@@finalpunct{\ifnum\lastkern=\m@ne\unkern\fi\refquotes@
    \if@finalpunct@.\fi
    \nobreak\CurrentBib\refbreak@AB@@}%
\newbox\holdoverbox
\def\BR@backref#1{\newblock \begingroup \csname @safe@activestrue\endcsname \expandafter 
    \providecommand \csname brc@#1\endcsname {0}\expandafter 
    \providecommand \csname brcd@#1\endcsname {0}\csname @safe@activesfalse\expandafter 
    \endcsname \ifBR@BackrefAlt \ifx \backrefentrycount \BR@BackrefEntryCountUnused 
    \else \BR@PopulateEntryCount {#1}\fi \expandafter \backrefalt \csname brc@#1\expandafter 
    \endcsname \csname brl@#1\expandafter \endcsname \csname brcd@#1\expandafter \endcsname 
    \csname brld@#1\endcsname \else \expandafter \backref \csname br@#1\expandafter 
    \endcsname \fi \endgroup }
\newbox\translbox@AB@
\def\transl@#1{\unskip\unskip
    \makerefbox@AB@\z@{\@@par\egroup}%
    \let\savedef@\finalpunct  \let\finalpunct\empty \end@ref@
    \book@false\procpaper@false #1
    \def\punct@##1##2{\unskip\unskip ##2{\@No@Color;}\allowbreak\ }%
    \global\let\nofrills@list\empty%
    \let\finalpunct\savedef@ \moreref@true
    \def\curbox{\translbox@AB@}%
    \setbox\translbox@AB@\vbox\bgroup \hsize\maxdimen \noindent
    \misc@\nofrills}%
%
\def\punct@#1{#1}
\def\commaunbox@AB@#1{\ppunbox@AB@,\space{#1}\empty}
\def\pnktunbox@AB@#1{\ppunbox@AB@.\space{#1}\empty}%
\def\pnktunbox@AB@#1{\ppunbox@AB@\empty\space{#1}\empty}%
\def\ppunbox@AB@#1#2#3#4{\ifvoid#3\else
  \let\prespace@\relax
  \ifnum\lastkern=\m@ne \unkern\let\punct@\@gobble
    \ifnum\lastkern=-\tw@ \unkern\let\prespace@\ignorespaces \fi
  \fi
  \nofrillscheck#3%
  \punct@{#1}\refquotes@\refbreak@AB@@
  \let\punct@\@firstofone
  \prespace@
  \frills@{#2\@gobble}\space
  \unhbox#3\breakcheck
  \frills@{#4\@gobble}{\kern\m@ne sp}\fi}
\def\nofrills@@#1{\DN@{#1}\ifx\next\nofrills \let\frills@\@gobble
   \expandafter\expandafter\expandafter\next@\expandafter\@gobble
  \else \let\frills@\@firstofone\expandafter\next@\fi}
\def\nofrillscheck#1{\def\nofrills@{\nofrills@@{#1}}%
  \futurelet\next\nofrills@}
\def\newpage@AB@{\vadjust{\vfill\break@AB@}}%
\def\break@AB@{\holdover{\penalty -\@M}}%
\def\linebreak@AB@{\holdover{\penalty -\@M}}%
\def\newline@AB@{\holdover{\hfill\penalty -\@M}}%
\def\endline@AB@{\holdover{\hfill\penalty -\@M}}%
\let\vadjust@\vadjust
\def\vadjust@AB@#1{\holdover{\vadjust@{#1}}}%
\def\breakcheck{\edef\refbreak@AB@@{\ifnum\lastpenalty=\z@\else
  \penalty\the\lastpenalty\relax\fi}\unpenalty}

\gdef\@@ref{%
    \ppunbox@AB@\empty\space\misc@box@AB@\empty%
    \ppunbox@AB@\empty\space\bybox@AB@\empty%
    \ifbook@% Case 1: \book etc.
        \ppunbox@AB@{.}{ }\bookbox@AB@\empty
        \ppunbox@AB@{,}{ }\bookinfobox@AB@\empty
        \ppunbox@AB@{.}{ \bibbookVoltext~}\bookvolbox@AB@\empty
        \ppunbox@AB@{:}{ \voltitletext@}\voltitlebox@AB@\empty
        \ppunbox@AB@{,}{ }\procbox@AB@\empty%
        \ppunbox@AB@{}{ (}\procinfobox@AB@)%
        \ppunbox@AB@{,}{ }\serialbox@AB@{}%
        \ppunbox@AB@{,}{ \bibvoltext~}\volbox@AB@\empty
        \ppunbox@AB@,{ \volinfotext@ }\volinfobox@AB@\empty
        \ppunbox@AB@,{ \bibserissuetext@ }\serissuebox@AB@\empty
        \ppunbox@AB@,{ \issueinfotext@ }\issueinfobox@AB@\empty
        \ppunbox@AB@{,}{ }\editionbox@AB@ \empty%
        \ppunbox@AB@{,}{ \bibedtext~}\edbox@AB@ \empty%
        \ppunbox@AB@{,}{ \bibedstext~}\edsbox@AB@ \empty%
        \ppunbox@AB@{,}{ }\finalbookinfobox@AB@\empty
        \ppunbox@AB@{,}{ }\publbox@AB@ \empty
        \ppunbox@AB@{,}{ }\publaddrbox@AB@{}%
        \ppunbox@AB@{;}{ }\publlbox@AB@ \empty
        \ppunbox@AB@{,}{ }\publaddrrbox@AB@{}%
        \ppunbox@AB@{;}{ }\publllbox@AB@ \empty
        \ppunbox@AB@{,}{ }\publaddrrrbox@AB@{}%
        \ppunbox@AB@,{ }\yrbox@AB@{}%
        \ppunbox@AB@,{ \isbntext@ }\isbnbox@AB@{}%
        \else
        \ifprocpaper@ % Case 2: \paper ... \inbook
            \ifvoid \byybox@AB@
                \ppunbox@AB@{.}{ \openquote@AB@}\paperbox@AB@{\closequote@AB@}%
                \ppunbox@AB@{,}{ }\paperinfobox@AB@{}%
            \else
                \ppunbox@AB@{,}{ \openquote@AB@}\paperbox@AB@{\closequote@AB@}%
                \ppunbox@AB@{,}{ }\paperinfobox@AB@{}%
                \ppunbox@AB@{:}{ \byytext@ }\byybox@AB@\empty%
            \fi
            \ppunbox@AB@{,}{ \inbook@text }\bookbox@AB@\empty
            \ppunbox@AB@{,}{ }\bookinfobox@AB@\empty
            \ppunbox@AB@{.}{ \bibbookVoltext~}\bookvolbox@AB@\empty
            \ppunbox@AB@{:}{ \voltitletext@}\voltitlebox@AB@\empty
            \ppunbox@AB@{,}{ }\procbox@AB@\empty%
            \ppunbox@AB@{}{ (}\procinfobox@AB@)%
            \ppunbox@AB@{,}{ }\serialbox@AB@{}%
            \ppunbox@AB@{,}{ \bibvoltext~}\volbox@AB@\empty
            \ppunbox@AB@,{ \volinfotext@ }\volinfobox@AB@\empty
            \ppunbox@AB@,{ \bibserissuetext@ }\serissuebox@AB@\empty
            \ppunbox@AB@,{ \issueinfotext@ }\issueinfobox@AB@\empty
            \ppunbox@AB@{,}{ }\editionbox@AB@ \empty%
            \ppunbox@AB@{,}{ \bibedtext~}\edbox@AB@ \empty%
            \ppunbox@AB@{,}{ \bibedstext~}\edsbox@AB@ \empty%
            \ppunbox@AB@{,}{ }\finalbookinfobox@AB@\empty
            \ppunbox@AB@{,}{ }\publbox@AB@ \empty
            \ppunbox@AB@{,}{ }\publaddrbox@AB@{}%
            \ppunbox@AB@{;}{ }\publlbox@AB@ \empty
            \ppunbox@AB@{,}{ }\publaddrrbox@AB@{}%
            \ppunbox@AB@{;}{ }\publllbox@AB@ \empty
            \ppunbox@AB@{,}{ }\publaddrrrbox@AB@{}%
            \ifvoid \monthissuebox@AB@
                \ppunbox@AB@,{ }\yrbox@AB@{}%
            \else
                \ppunbox@AB@,{ }\monthissuebox@AB@\empty
                \ppunbox@AB@{}{ }\yrbox@AB@{}%
            \fi
            \ppunbox@AB@{,}{ \bibpagestext~}\pagesbox@AB@\empty
            \ppunbox@AB@,{ \isbntext@ }\isbnbox@AB@{}%
        \else % Case 3: \paper ... \jour
            \ppunbox@AB@{.}{ \openquote@AB@}\paperbox@AB@{\closequote@AB@}%
            \ppunbox@AB@{,}{ }\paperinfobox@AB@{}%
            \ppunbox@AB@{,}{ \proc@text@}\procbox@AB@{}%
            \ppunbox@AB@{}{ (}\procinfobox@AB@)%
            \ppunbox@AB@{,}{ }\jourbox@AB@{}%
            \ifvoid\volbox@AB@
                \ppunbox@AB@{,}{ }\yrbox@AB@{}%
                \ppunbox@AB@{,}{ \volinfotext@}\volinfobox@AB@\empty
                \ppunbox@AB@{,}{ \bibissuetext}\issuebox@AB@\empty
                \ppunbox@AB@{,}{ \issueinfotext@}\issueinfobox@AB@\empty
            \else
                \ppunbox@AB@{,}{ }\volbox@AB@\empty
                \ppunbox@AB@{,}{ }\volinfobox@AB@\empty
                \ppunbox@AB@:{}\issuebox@AB@\empty
                \ppunbox@AB@{,}{ \issueinfotext@}\issueinfobox@AB@\empty
                \ifvoid \monthissuebox@AB@
                    \ppunbox@AB@{}{ (}\yrbox@AB@{)}%
                \else
                    \ppunbox@AB@{}{ (}\monthissuebox@AB@\empty
                    \ppunbox@AB@{}{ }\yrbox@AB@{)}%
                \fi
            \fi
            \ppunbox@AB@,{ \bibpagestext~}\pagesbox@AB@\empty
            \ppunbox@AB@,{ \paperidtext@ }\paperidbox@AB@\empty
        \fi
    \fi
    \ppunbox@AB@\empty{ (}\miscnotebox@AB@)%
    \ppunbox@AB@\empty{ \ (}\langbox@AB@{)}%
    \ppunbox@AB@,{ }\totalpagesbox@AB@{\totalpagestext@}%
    \ppunbox@AB@,{\hskip3ptplus3mmminus1mm\elinktext@ }\elinkbox@AB@{}%
    \ppunbox@AB@,{ \arxivtext@ }\arxivbox@AB@{}%
    \ppunbox@AB@{,}{ }\finalinfobox@AB@\empty
    \ppunbox@AB@\empty{ (\withtext}\withbox@AB@)%
    \ppunbox@AB@\empty{ }\@@finalinfobox@AB@\empty
    \finalpunct
}%

%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\arxiv{\global\@finalpunct@true\makerefbox@AB@\arxivbox@AB@\empty}\newbox\arxivbox@AB@
\def\arxivtext@{arXiv:\,\allowbreak}
\def\bookinfo{\makerefbox@AB@\bookinfobox@AB@{\rm \aftergroup\procpaper@true\aftergroup\book@false}}\newbox\bookinfobox@AB@
\def\book{\makerefbox@AB@\bookbox@AB@{\it \aftergroup\book@true\aftergroup\procpaper@false}}\newbox\bookbox@AB@
\def\bookvol{\makerefbox@AB@\bookvolbox@AB@\empty}\newbox\bookvolbox@AB@
\def\by{\makerefbox@AB@\bybox@AB@{\empty\rm}}\newbox\bybox@AB@
\def\bysame{\by\hbox to3em{\hrulefill}\thinspace\kern\z@}%
\def\byy{\makerefbox@AB@\byybox@AB@\empty}\newbox\byybox@AB@\let\byytext@\empty
\def\continuepunct#1#2#3#4{}%
\def\crossref#1{\ignorespaces}
\def\edition{\makerefbox@AB@\editionbox@AB@\empty}\newbox\editionbox@AB@
\def\ed{\makerefbox@AB@\edbox@AB@\empty}\newbox\edbox@AB@
\def\eds{\makerefbox@AB@\edsbox@AB@\empty}\newbox\edsbox@AB@
\def\elink{\global\@finalpunct@false\makerefbox@AB@\elinkbox@AB@\empty\elinkurl}\newbox\elinkbox@AB@
\def\elinktext@{{\elinktext@size \textsf{URL}:\hskip3ptplus3mm}}
\def\elinkurl{\elink@url@size\ttfamily\futurelet\next\elink@url}\def\elink@url{\ifx\next\bgroup\expandafter\url\fi}
\def\endquotes{\def\refquotes@{''\let\refquotes@\empty}}
\def\finalbookinfo{\makerefbox@AB@\finalbookinfobox@AB@\empty}\newbox\finalbookinfobox@AB@
\def\@@finalinfo{\global\@finalpunct@true\makerefbox@AB@\@@finalinfobox@AB@\empty}\newbox\@@finalinfobox@AB@
\def\finalinfo{\global\@finalpunct@true\makerefbox@AB@\finalinfobox@AB@\empty}\newbox\finalinfobox@AB@
\def\inbook{\makerefbox@AB@\bookbox@AB@{\it \aftergroup\procpaper@true\aftergroup\book@false}}\let\inbook@text\empty
\def\isbn{\makerefbox@AB@\isbnbox@AB@\empty}\newbox\isbnbox@AB@ \def\isbntext@{ISBN: }
\def\isi#1{\ignorespaces}
\def\issueinfo{\makerefbox@AB@\issueinfobox@AB@\empty}\newbox\issueinfobox@AB@\let\issueinfotext@\empty
\def\issue{\makerefbox@AB@\issuebox@AB@\empty} \newbox\issuebox@AB@
\def\jour{\makerefbox@AB@\jourbox@AB@{\it\aftergroup\jour@true}}\newbox\jourbox@AB@
\def\jour@true{\global\book@false\global\procpaper@false}%
\def\lang{\makerefbox@AB@\langbox@AB@\empty} \newbox\langbox@AB@
\def\mathnet#1{\ignorespaces}
\def\misc@{\makerefbox@AB@\misc@box@AB@\empty\ifx\cyrillicencoding\@undefined\else\select@language{russian}\fi}\newbox\misc@box@AB@
\def\miscnote{\makerefbox@AB@\miscnotebox@AB@\empty} \newbox\miscnotebox@AB@
\def\monthissue{\makerefbox@AB@\monthissuebox@AB@\empty}\newbox\monthissuebox@AB@\let\monthissuetext@\empty
\def\moreref{\transl@\defaultreftexts}\let\transl\moreref
\def\morerref{\transl@\defaultrusreftexts}\let\rtransl\morerref
\def\@No@Color{\textcolor{black}}
\def\normalrefs{\global\let\elink@url@size\small\global\let\elinktext@size\footnotesize}\normalrefs
\def\page{\global\let\page@text=\bibpagetext\makerefbox@AB@\pagesbox@AB@\empty}\global\let\page@text=\bibpagestext
\def\pages{\global\let\page@text=\bibpagestext\makerefbox@AB@\pagesbox@AB@\empty}\newbox\pagesbox@AB@
\def\paperinfo{\makerefbox@AB@\paperinfobox@AB@\empty}\newbox\paperinfobox@AB@
\def\paper{\makerefbox@AB@\paperbox@AB@\empty}\newbox\paperbox@AB@
\def\papernumber{\makerefbox@AB@\paperidbox@AB@\empty}\newbox\paperidbox@AB@\def\paperidtext@{}
\def\preprintinfo{\makerefbox@AB@\bookinfobox@AB@{\aftergroup\book@true\rm \let\@my@href=\href\relax\def\href##1##2{\@my@href{##1}{{\tt ##2}}}}}
\def\procinfo{\makerefbox@AB@\procinfobox@AB@\empty}\newbox\procinfobox@AB@\let\proc@text@\empty
\def\proc{\makerefbox@AB@\procbox@AB@\empty}\newbox\procbox@AB@
\def\publaddr{\makerefbox@AB@\publaddrbox@AB@\empty}\newbox\publaddrbox@AB@
\def\publaddrr{\makerefbox@AB@\publaddrrbox@AB@\empty}\newbox\publaddrrbox@AB@
\def\publaddrrr{\makerefbox@AB@\publaddrrrbox@AB@\empty}\newbox\publaddrrrbox@AB@
\def\publll{\makerefbox@AB@\publllbox@AB@\empty}\newbox\publllbox@AB@
\def\publl{\makerefbox@AB@\publlbox@AB@\empty}\newbox\publlbox@AB@
\def\publ{\makerefbox@AB@\publbox@AB@\empty} \newbox\publbox@AB@
\def\raggedref{\par\rightskip 0mmplus7mm\par\rightskip 0mm\par}
\def\scopus#1{\ignorespaces}
\def\serial{\makerefbox@AB@\serialbox@AB@{\rm \aftergroup\procpaper@true\aftergroup\book@false}}\newbox\serialbox@AB@
\def\serissue{\makerefbox@AB@\serissuebox@AB@\empty}\newbox\serissuebox@AB@
\def\smallerrefs{\global\let\elink@url@size\footnotesize\global\let\elinktext@size\scriptsize}%
\def\toappear{\miscnote \bibt@appear}%
\def\totalpages{\global\@finalpunct@false\makerefbox@AB@\totalpagesbox@AB@\empty}\newbox\totalpagesbox@AB@\def\totalpagestext@{~\bibpagetext}%
\def\volinfo@AB@{\makerefbox@AB@\volinfobox@AB@\empty}\newbox\volinfobox@AB@
\def\volinfotext@{}
\def\vol{\makerefbox@AB@\volbox@AB@{\bf}}\newbox\volbox@AB@
\def\voltitle{\makerefbox@AB@\voltitlebox@AB@{\it}}\newbox\voltitlebox@AB@\let\voltitletext@\empty
\def\with{\makerefbox@AB@\withbox@AB@{\empty\rmfamily}}\newbox\withbox@AB@
\def\yr{\makerefbox@AB@\yrbox@AB@\empty} \newbox\yrbox@AB@
\let\bookvols=\bookvol
\let\eprintinfo=\preprintinfo
\let\manyby=\by % for backward compatibility
\let\paperid=\papernumber
\let\preprint=\book \let\eprint=\preprint
\let\refbreak@AB@@=\empty
\let\refquotes@\empty
\let\thesisinfo=\preprintinfo
\let\thesis=\preprint
\let\finalpunct=\@@finalpunct


%%%%%%%%%%%%%%% TOC
\def\psta@if@has@minus#1-#2#3\end@test@minus{\if;#2\expandafter\@secondoftwo\else\expandafter\@firstoftwo\fi}
\def\PageLink#1#2{#2}
%
\def\boldtocpages#1{\subsection*{\Title}\addcontentsline{toc}{subsection}{\Title}\let\Title\@empty}
\long\def\tocpages#1#2{\baselineskip11pt 
    \leftskip=1em\parindent-\leftskip \rightskip 14mm \parfillskip-\rightskip
    \parskip 2mmplus2mm
    \def\\{\unskip\space\ignorespaces}\let\ =\\ 
    \@@par\spaceskip3ptplus8ptminus2pt
    \ifx\Author\@empty \else{\small\textsc{\Author}~}\fi
    \ifx\Title\@empty \else   {%\small
       \itshape{\Title\nobreak}}%
    \@ifempty{#1}{}{\nobreak{ \small\dotfill}\hbox{ \em{\LastPagerange{#1}{#2}}}}\fi\@@par
    \let\Author\@empty\let\Title\@empty}
\let\Title\@empty \let\Author\@empty
%
\def\NonLastPagerange#1#2{\FormatPagerange{}{}{#2}{#1}, }
\def\LastPagerange#1#2{\FormatPagerange{\hbox to 8mm}{\hss}{#2}{#1}}
\def\FormatPagerange#1#2#3#4{\psta@if@has@minus#4-;\end@test@minus{\FormatPagerange@{#1}{#2}{#3}#4\endFormatPagerange@}{\PageLink{#3}{#4}#1{#2}}}
\def\FormatPagerange@#1#2#3#4-#5\endFormatPagerange@{\PageLink{#3}{#4}\textcolor{lightgray}{#1{\small\,--\,\PageLink{#3}{#5}#2}}}
\let\AUpages\LastPagerange
%
\def\tocsection#1{{\everypar{}\bigskip\noindent\parfillskip \z@
        \leftskip .2\hsize plus.2 \hsize minus .2\hsize
        \rightskip\leftskip
        \textsf{#1}\par}}
%

\def\ell@#1{\strut\nobreak\hskip \z@ plus#1\hsize}
\def\boldfirst#1,{{\small\textsc{#1}},}
\def\AUauthor#1#2#3#4{{\parskip 2.5mmplus1mm
    \baselineskip10pt \spaceskip3ptplus8ptminus2pt
    \leftskip1em \parindent-\leftskip\rightskip14mm
    \boldfirst#1\ell@1\penalty2000\space\ell@8% 
    \lower1pt\hbox{\textcolor{lightgray}{{\tiny${}_{}^<$}}}%
    {\footnotesize\textsf{\href{mailto:#2}{#2}}}%
    \lower1pt\hbox{\textcolor{lightgray}{{\tiny${}_{}^>$}}}
    \ell@1\penalty3000\space\ell@1  
    \hbox {#4\hskip -14mm}\break
    \Small\emph{#3}\@@par\pagebreak[2]}}%
%
\def\tocwrite#1{\def\Title{#1}}%   
\long\def\theabstract#1{\def\Abstract{#1}}%
\def\directiontitle#1#2{\subsection*{#1}\thispagestyle{firstpage}}%
\def\toctitle#1#2{\hypertarget{#2}{\section*{#1}}\thispagestyle{firstpage}\let\Title\@empty\thetitle
    {#1}\markboth{#1}{#1}}%
\def\thetitle#1{\def\Title{#1}}
\def\theauthor#1{\def\Author{#1}}%
\expandafter\ifx \csname forVolumes\endcsname\relax
\def\forVolumes{\expandafter\forVolumes@\jobname\relax}%
\def\forVolumes@#1#2\relax{\if1#1\expandafter\@firstoftwo\else
    \expandafter\@secondoftwo\fi}\fi
\gdef\psta#1{\if-#1\expandafter\psta@\fi}
\gdef\psta@#1 #2 \psta{\expandafter\xdef\csname psta-#1\endcsname{#2}\psta}
\if\PSTAforUGP
\gdef\englishfootnotetexttosection{}
\gdef\russianfootnotetexttosection{}
\catcode45 =13
\def-{\=/}
\def\tosectionitem#1\item#2- #3\item{\@ifempty{#2}{\egroup\end{tosection}}{
    \expandafter\g@addto@macro\csname\languagename footnotetexttosection\endcsname
    {\set@tosection#3#2- -.}\tosectionitem\item}}
\def\tosectioncoma{\xdef\tosectioncoma{, }}
\def\set@tosection#1#2 -#3.{{\ifcase#1\or\tosectioncoma\scriptsize\textrm{#2}\or\tosectioncoma\scriptsize\textit{#2}\fi}}
\def\tosection{\bgroup\catcode13=10\catcode45=13  \toSection}
\def\endtosection{}
\def\toSection#1\end#2{\tosectionitem#1 \item - 1 \item}
 \def\EnglishTeacher#1{}
\catcode 45=12
\fi
\ifx \No\undefined \DeclareRobustCommand{\No}{\ifmmode{\nfss@text{\textnumero}}\else\textnumero\fi}\fi
\inputencoding{\DocumentEncoding}\makeatletter
\InputIfFileExists{psta-\DocumentEncoding.sty}{}{}
\if y\hyphenbreaks \g@addto@macro\UrlBreaks{\do-}\fi
\AtBeginDocument{\expandafter\selectlanguage\expandafter{\document@language}\advance\baselineskip 0ptplus.35ptminus.25pt}

\if\UGPDOC
\def\Referat#1{\def\UGP@referat{#1}}
%\tracingall
\def\speciality#1{\def\thespeciality{#1}}
\def\@maketitle{% inside group
  \normalfont\normalsize
  \vbox to\vsize{\null\vskip-14pt
      \UGP@name
  \let\@makefnmark\relax  \let\@thefnmark\relax
%\@ifrus{\l@nameuse{setsubjclasses}}{}
  %\set@thanks@address
  \global\topskip0pc\relax % 10pc to base of first title line
  \expandafter\begingroup\trivlist
      \centering 
       \fontsize{11}{13\p@}\selectfont\@topsep13\p@\relax
      \item\relax
       %   \tracingall
      \def\\{\protect\linebreak}%
      \@ifundefined{thespeciality}{\bigskip}{
         \UGP@ea\formatUGPspeciality\thespeciality}
  \vskip32ptplus32pt
  \l@ifundefined{title}{\errmessage{Need \string\title\{...\}!
    }}{\let\subtitle\displaysubtitle {\Large\textbf{\l@nameuse{title}}\\}}
  \vskip0ptplus4pt
  {\small\textsf{\@ifundefined{UGP@referat}{\UGP@Courseworkname}{\UGP@Referatname}} \textit{ \UGP@worktime{\expandafter
    \uppercase\expandafter{\romannumeral\UGP@work@kurs}}}\\}
  \vskip32ptplus32pt
  \begin{tabular}{m{.45\hsize}cm{.45\hsize}}
   {\textsf{\UGP@ea \UGP@sex\UGP@vypolnil:}}\newline
  \strut\hskip2mmplus8cm\textsf{\UGP@ea \UGP@sex\UGP@student}~\textrm{\expandafter
  \uppercase\expandafter{\romannumeral\UGP@student@kurs}~\UGP@kursa\break
   \strut\hskip2mmplus4cm\UGP@gruppy~\UGP@group\break}
    \ifcase\l@nameuse{author.id}\or\else\errmessage{Only one author is allowed!}\fi
    \baselineskip0pt\vskip2pt
    \rlap{\textbf{\textit{\expandafter\expandafter\expandafter
    \formatUGPstudent\csname\languagename-author.1\endcsname\endswap@fio}}}
    \vskip1mm
    \UGP@stamp{\UGP@ea \UGP@sex\UGP@studenta}
   &\hbox{\hskip4mm}&\l@ifundefined{tutor.id}{\errmessage{Need \tutor\{..., ... ...\}!}}
   %\parindent0pt
   \raggedright
     \textsf{\ifcase \@nameuse{tutor.id}\or \advisorname\else\advisorsname\fi:}\par\raggedleft
    \l@nameuse{tutor-s.list}
    \@ifundefined{UGP@chairman}{}{\vskip5mm
    \raggedright\textsf{\UGP@chairname}\par\raggedleft\leftskip-8mmplus.5\hsize \UGP@chairtitle:\break 
    \textit{\UGP@chairmantitle~\textbf{\UGP@chairman}}
    \UGP@stamp{}}
    \end{tabular}
\vskip32ptplus32pt
\Townname
\par
\Year
\par
\endgroup        
}
\@ifundefined{UGP@referat}{%
\vbox to\vsize{\vfil
\l@ifundefined{abstract}{\errmessage{Abstract is necessary!}}{%
\section*{\UGP@referat@name}%\tracingall
        \textit{\expandafter\expandafter\expandafter
            \swap@fio\csname\languagename-author.1\endcsname\endswap@fio.} 
        \textbf{\l@nameuse{title}} (\UGP@referat@name \textit{ \UGP@worktime{\expandafter
    \uppercase\expandafter{\romannumeral\UGP@work@kurs}}}) -- \pageref{LastPage}~\bibpagetext\iftotalfigures
        ,    \totalfigures~\UGP@picname.\fi\iftotaltables
        ,     \totaltables~\UGP@tablname.\fi\@ifundefined{totalbibitems}{}{,   
                \totalbibitems~\expandafter\cyrending@@\UGP@bibitemsname\totalbibitems.}
        \vskip1ex
        \begin{raggedright}
        \small\noindent\textsc{\l@nameuse{keywords}}
        \end{raggedright}
        \vskip2ex
        \l@nameuse{abstract}\endlist}
    \vfil\null
        \prevdepth\z@}
  \normalsize
    \dimen@20\p@ \advance\dimen@-\baselineskip
    \vskip\dimen@\relax
  \let\subtitle\inlinesubtitle
  \newpage
}{ % else Referat  
    \l@ifundefined{abstract}{\errmessage{Abstract is necessary!}}{{%\spaceskip1.5mmplus1.5mmminus.5mm 
    \textsc{\UGP@Annotaciya .} %\tracingall
      \textit{\l@nameuse{title}} (\UGP@referat@name \textit{ \UGP@worktime{\expandafter
      \uppercase\expandafter{\romannumeral\UGP@work@kurs}}} \UGP@ea \UGP@sex\UGP@vypolnil{}
      \textrm{  \expandafter\expandafter\expandafter
    \formatUGPstudent\csname\languagename-author.1\endcsname\endswap@fio}).\par 
    \l@nameuse{abstract}-- \pageref{LastPage}~\bibpagetext\iftotalfigures
        ,    \totalfigures~\UGP@picname.\fi \iftotaltables
        ,     \totaltables~\UGP@tablname.\fi\@ifundefined{totalbibitems}{}{,   
\totalbibitems~\expandafter\cyrending@@\UGP@bibitemsname\totalbibitems.}}}
        \vskip2ex
        \begin{raggedright}
            \small\noindent\textbf{\keywordsname}: \textrm{\l@nameuse{keywords}}
        \end{raggedright}
  \normalsize
    \dimen@20\p@ \advance\dimen@-\baselineskip
    \vskip\dimen@\relax
  \let\subtitle\inlinesubtitle
  }} % end \@maketitle%
\let\publname\UGP@name
\let\address@@\address
\def\info#1{\address@@{#1}\UGP@info#1.}
\let\address\info 
\def\UGP@info#1, #2#3#4.{\@ifrus{\def \UGP@student@kurs{#2}\def\UGP@work@kurs{#2}\def \UGP@group{#2#3#4}}{\def\thespeciality{\csname UGP@speciality#3\endcsname}}}
\def\years#1, #2.{\def \UGP@work@kurs{#1}\def\Year{#2}}
\def\formatUGPspeciality#1#2{{\small
        \begin{tabular}{ll}
        \textsf{\UGP@specialityname:}\quad & \textit{#1}\\
        \@ifempty{#2}{\textsf{\UGP@profilename:} & \textit{#1}\\}{\textsf{\UGP@profilename:} & \textit{#2}\\}
        \end{tabular}}}
\def\femalestudent{\xdef\UGP@sex##1##2##3{##1##3}}\xdef\UGP@sex#1#2#3{#1#2}
\def\UGP@ea{\expandafter\expandafter\expandafter\expandafter
          \expandafter\expandafter\expandafter}
\def\formatUGPstudent#1, #2 #3\endswap@fio{#2 #1} 
\def\UGP@stamp#1{\vbox{\offinterlineskip\vskip 8mm
    \hrule
    \vskip2pt
    \hbox to\hsize{\hskip2mmplus1cm{\tiny\textsf{\UGP@signature#1}}\hskip2mmplus1cm}
    \vskip1ex
    \hbox to \hsize{<<\qquad>> \hrulefill\ \Year}}}
\@namedef{tutor-format}#1{\expandafter\expandafter\expandafter
    \UGP@tutorstamp\csname russian-tutor.#1\endcsname\null{#1}}
    \def\UGP@tutorstamp#1,#2,#3,#4\null#5{\par\raggedleft\leftskip-8mmplus.5\hsize \textit{#4 \textbf{\l@nameuse{tutor.#5.initials}~#1} \textit{#3}}\linebreak
    \UGP@stamp{}\bigskip}
\def\chair#1#2#3{\def\UGP@chairtitle{#1}\def\UGP@chairmantitle{#2}\def\UGP@chairman{#3}} 
\def\cyrending@#1#2#3#4{\ifnum#1>100 \cyrending@{\numexpr#1-100\relax}{#2}{#3}{#4}\else
    \ifnum#1 < 21 \ifnum#1> 4 #4\else\ifnum#1=1 #2 \else#3\fi\fi\else
    \ifnum#1 < 31 \cyrending@{\numexpr#1-20\relax}{#2}{#3}{#4}\else
    \cyrending@{\numexpr#1-10\relax}{#2}{#3}{#4}\fi\fi\fi}
\def\cyrending@@#1#2#3#4#5{#1\cyrending@{#5}{#2}{#3}{#4}}
\let\@set@ssylka\vfill
\fi

\endinput

% vim:ts=4:expandtab:syn=tex
